@@ -16,12 +16,10 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-cookie-manager.c,v 1.5 2004/01/01 22:54:10 chpe Exp $
+ *  $Id: ephy-cookie-manager.c,v 1.8 2004/11/02 20:56:55 chpe Exp $
  */
 
-#ifdef HAVE_CONFIG_H
 #include "config.h"
-#endif
 
 #include "ephy-cookie-manager.h"
 
@@ -30,7 +28,7 @@ ephy_cookie_get_type (void)
 {
 	static GType type = 0;
 
-	if (type == 0)
+	if (G_UNLIKELY (type == 0))
 	{
 		type = g_boxed_type_register_static ("EphyCookie",
 						     (GBoxedCopyFunc) ephy_cookie_copy,
@@ -105,11 +103,11 @@ ephy_cookie_manager_get_type (void)
 {
        static GType type = 0;
 
-	if (type == 0)
+	if (G_UNLIKELY (type == 0))
 	{
 		static const GTypeInfo our_info =
 		{
-			sizeof (EphyCookieManagerIFace),
+			sizeof (EphyCookieManagerIface),
 			ephy_cookie_manager_base_init,
 			NULL,
 		};
@@ -140,7 +138,7 @@ ephy_cookie_manager_base_init (gpointer base_iface)
 	g_signal_new ("cookie-added",
 		      EPHY_TYPE_COOKIE_MANAGER,
 		      G_SIGNAL_RUN_FIRST,
-		      G_STRUCT_OFFSET (EphyCookieManagerIFace, added),
+		      G_STRUCT_OFFSET (EphyCookieManagerIface, added),
 		      NULL, NULL,
 		      g_cclosure_marshal_VOID__BOXED,
 		      G_TYPE_NONE,
@@ -157,7 +155,7 @@ ephy_cookie_manager_base_init (gpointer base_iface)
 	g_signal_new ("cookie-changed",
 		      EPHY_TYPE_COOKIE_MANAGER,
 		      G_SIGNAL_RUN_FIRST,
-		      G_STRUCT_OFFSET (EphyCookieManagerIFace, changed),
+		      G_STRUCT_OFFSET (EphyCookieManagerIface, changed),
 		      NULL, NULL,
 		      g_cclosure_marshal_VOID__BOXED,
 		      G_TYPE_NONE,
@@ -174,7 +172,7 @@ ephy_cookie_manager_base_init (gpointer base_iface)
 	g_signal_new ("cookie-deleted",
 		      EPHY_TYPE_COOKIE_MANAGER,
 		      G_SIGNAL_RUN_FIRST,
-		      G_STRUCT_OFFSET (EphyCookieManagerIFace, deleted),
+		      G_STRUCT_OFFSET (EphyCookieManagerIface, deleted),
 		      NULL, NULL,
 		      g_cclosure_marshal_VOID__BOXED,
 		      G_TYPE_NONE,
@@ -191,7 +189,7 @@ ephy_cookie_manager_base_init (gpointer base_iface)
 	g_signal_new ("cookie-rejected",
 		      EPHY_TYPE_COOKIE_MANAGER,
 		      G_SIGNAL_RUN_FIRST,
-		      G_STRUCT_OFFSET (EphyCookieManagerIFace, rejected),
+		      G_STRUCT_OFFSET (EphyCookieManagerIface, rejected),
 		      NULL, NULL,
 		      g_cclosure_marshal_VOID__STRING,
 		      G_TYPE_NONE,
@@ -208,7 +206,7 @@ ephy_cookie_manager_base_init (gpointer base_iface)
 	g_signal_new ("cookies-cleared",
 		      EPHY_TYPE_COOKIE_MANAGER,
 		      G_SIGNAL_RUN_FIRST,
-		      G_STRUCT_OFFSET (EphyCookieManagerIFace, cleared),
+		      G_STRUCT_OFFSET (EphyCookieManagerIface, cleared),
 		      NULL, NULL,
 		      g_cclosure_marshal_VOID__VOID,
 		      G_TYPE_NONE,
@@ -229,7 +227,7 @@ ephy_cookie_manager_base_init (gpointer base_iface)
 GList *
 ephy_cookie_manager_list_cookies (EphyCookieManager *manager)
 {
-	EphyCookieManagerIFace *iface = EPHY_COOKIE_MANAGER_GET_IFACE (manager);
+	EphyCookieManagerIface *iface = EPHY_COOKIE_MANAGER_GET_IFACE (manager);
 	return iface->list (manager);
 }
 
@@ -244,7 +242,7 @@ void
 ephy_cookie_manager_remove_cookie (EphyCookieManager *manager,
 				   const EphyCookie *cookie)
 {
-	EphyCookieManagerIFace *iface = EPHY_COOKIE_MANAGER_GET_IFACE (manager);
+	EphyCookieManagerIface *iface = EPHY_COOKIE_MANAGER_GET_IFACE (manager);
 	iface->remove (manager, cookie);
 }
 
@@ -257,6 +255,6 @@ ephy_cookie_manager_remove_cookie (EphyCookieManager *manager,
 void
 ephy_cookie_manager_clear (EphyCookieManager *manager)
 {
-	EphyCookieManagerIFace *iface = EPHY_COOKIE_MANAGER_GET_IFACE (manager);
+	EphyCookieManagerIface *iface = EPHY_COOKIE_MANAGER_GET_IFACE (manager);
 	iface->clear (manager);
 }
