@@ -15,25 +15,16 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-embed-event.c,v 1.12 2004/03/17 09:02:31 marco Exp $
+ *  $Id: ephy-embed-event.c,v 1.15 2004/11/02 20:56:55 chpe Exp $
  */
 
-#ifdef HAVE_CONFIG_H
 #include "config.h"
-#endif
 
 #include "ephy-embed-event.h"
 
 #include <glib/ghash.h>
 #include <gtk/gtktypeutils.h>
 
-#define EPHY_EMBED_EVENT_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object), EPHY_TYPE_EMBED_EVENT, EphyEmbedEventPrivate))
-
-struct EphyEmbedEventPrivate
-{
-	GHashTable *props;
-};
-
 static void ephy_embed_event_base_init (gpointer g_class);
 
 GType
@@ -41,7 +32,7 @@ ephy_embed_event_get_type (void)
 {
        static GType type = 0;
 
-	if (type == 0)
+	if (G_UNLIKELY (type == 0))
 	{
 		static const GTypeInfo our_info =
 		{
