@@ -15,12 +15,10 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-embed-shell.c,v 1.25 2004/10/27 19:54:56 chpe Exp $
+ *  $Id: ephy-embed-shell.c,v 1.26 2004/11/02 20:56:55 chpe Exp $
  */
 
-#ifdef HAVE_CONFIG_H
 #include "config.h"
-#endif
 
 #include "ephy-embed-shell.h"
 #include "ephy-embed-single.h"
