@@ -15,12 +15,10 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-embed.c,v 1.46 2004/10/30 17:46:05 chpe Exp $
+ *  $Id: ephy-embed.c,v 1.50 2004/12/19 13:26:37 chpe Exp $
  */
 
-#ifdef HAVE_CONFIG_H
 #include "config.h"
-#endif
 
 #include "ephy-embed.h"
 
@@ -33,9 +31,9 @@ static void ephy_embed_base_init (gpointer g_class);
 GType
 ephy_embed_chrome_get_type (void)
 {
-	static GType etype = 0;
+	static GType type = 0;
 
-	if (etype == 0)
+	if (G_UNLIKELY (type == 0))
 	{
 		static const GFlagsValue values[] =
 		{
@@ -46,10 +44,32 @@ ephy_embed_chrome_get_type (void)
 		{ 0, NULL, NULL }
 		};
 
-		etype = g_flags_register_static ("EphyEmbedChrome", values);
+		type = g_flags_register_static ("EphyEmbedChrome", values);
 	}
 
-	return etype;
+	return type;
+}
+
+GType
+ephy_embed_document_type_get_type (void)
+{
+	static GType type = 0;
+
+	if (G_UNLIKELY (type == 0))
+	{
+		static const GEnumValue values[] =
+		{
+		{ EMBED_DOCUMENT_HTML, "EMBED_DOCUMENT_HTML", "html" },
+		{ EMBED_DOCUMENT_XML, "EMBED_DOCUMENT_XML", "xml" },
+		{ EMBED_DOCUMENT_IMAGE, "EMBED_DOCUMENT_IMAGE", "image" },
+		{ EMBED_DOCUMENT_OTHER, "EMBED_DOCUMENT_OTHER", "other" },
+		{ 0, NULL, NULL }
+		};
+
+		type = g_enum_register_static ("EphyEmbedDocumentType", values);
+	}
+
+	return type;
 }
 
 GType
@@ -320,6 +340,23 @@ ephy_embed_base_init (gpointer g_class)
 			      G_TYPE_NONE,
 			      0);
 
+/**
+ * EphyEmbed::ge-document-type:
+ * @embed:
+ * @type: the new document type
+ *
+ * The ::ge-document-type signal is emitted when @embed determines the type of its document.
+ **/
+		g_signal_new ("ge_document_type",
+			      EPHY_TYPE_EMBED,
+			      G_SIGNAL_RUN_FIRST,
+			      G_STRUCT_OFFSET (EphyEmbedIface, document_type),
+			      NULL, NULL,
+			      g_cclosure_marshal_VOID__ENUM,
+			      G_TYPE_NONE,
+			      1,
+			      EPHY_TYPE_EMBED_DOCUMENT_TYPE);
+
 		initialized = TRUE;
 	}
 }
@@ -669,6 +706,19 @@ ephy_embed_get_security_level (EphyEmbed *embed,
 	EphyEmbedIface *iface = EPHY_EMBED_GET_IFACE (embed);
 	iface->get_security_level (embed, level, description);
 }
+/**
+ * ephy_embed_show_page_certificate:
+ * @embed: an #EphyEmbed
+ *
+ * Shows a dialogue displaying the certificate of the currently loaded page
+ * of @embed, if it was loaded over a secure connection; else does nothing.
+ **/
+void
+ephy_embed_show_page_certificate (EphyEmbed *embed)
+{
+	EphyEmbedIface *iface = EPHY_EMBED_GET_IFACE (embed);
+	iface->show_page_certificate (embed);
+}
 
 /**
  * ephy_embed_find_set_properties:
