@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-embed.h,v 1.44 2004/11/16 14:21:23 chpe Exp $
+ *  $Id: ephy-embed.h,v 1.45 2004/12/18 19:40:08 chpe Exp $
  */
 
 #ifndef EPHY_EMBED_H
@@ -37,6 +37,7 @@ G_BEGIN_DECLS
 #define EPHY_EMBED_GET_IFACE(inst)	(G_TYPE_INSTANCE_GET_INTERFACE ((inst), EPHY_TYPE_EMBED, EphyEmbedIface))
 
 #define EPHY_TYPE_EMBED_CHROME_MASK     (ephy_embed_chrome_get_type ())
+#define EPHY_TYPE_EMBED_DOCUMENT_TYPE	(ephy_embed_document_type_get_type ())
 
 typedef struct _EphyEmbed	EphyEmbed;
 typedef struct _EphyEmbedIface	EphyEmbedIface;
@@ -88,6 +89,14 @@ typedef enum
 	STATE_IS_SECURE_HIGH
 } EmbedSecurityLevel;
 
+typedef enum
+{
+	EMBED_DOCUMENT_HTML,
+	EMBED_DOCUMENT_XML,
+	EMBED_DOCUMENT_IMAGE,
+	EMBED_DOCUMENT_OTHER
+} EmbedDocumentType;
+
 struct _EphyEmbedIface
 {
 	GTypeInterface base_iface;
@@ -133,6 +142,8 @@ struct _EphyEmbedIface
 					 const char *uri);
 	gboolean (* modal_alert)	(EphyEmbed *embed);
 	void	 (* modal_alert_closed)	(EphyEmbed *embed);
+	void	 (* document_type)	(EphyEmbed *embed,
+					 EmbedDocumentType type);
 
 	/* Methods  */
 	void		   (* load_url)			(EphyEmbed *embed,
@@ -192,6 +203,8 @@ struct _EphyEmbedIface
 
 GType		  ephy_embed_chrome_get_type		(void);
 
+GType		  ephy_embed_document_type_get_type	(void);
+
 GType		  ephy_embed_get_type			(void);
 
 /* Base */
