@@ -16,15 +16,12 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-encodings.c,v 1.9 2004/01/06 15:53:49 chpe Exp $
+ *  $Id: ephy-encodings.c,v 1.17 2004/12/13 18:58:58 chpe Exp $
  */
 
-#ifdef HAVE_CONFIG_H
 #include "config.h"
-#endif
 
 #include "ephy-encodings.h"
-#include "ephy-string.h"
 #include "ephy-node-db.h"
 #include "ephy-file-helpers.h"
 #include "eel-gconf-extensions.h"
@@ -115,16 +112,13 @@ encoding_entries [] =
 	{ N_("R_omanian (ISO-8859-16)"),            "ISO-8859-16",           LG_SE_EUROPEAN,	FALSE },
 	{ N_("South _European (ISO-8859-3)"),	    "ISO-8859-3",            LG_SE_EUROPEAN,	FALSE },
 	{ N_("Thai (TIS-_620)"),                    "TIS-620",               LG_THAI,		FALSE },
-#if MOZILLA_SNAPSHOT >= 10 
 	{ N_("Thai (IS_O-8859-11)"),                "iso-8859-11",           LG_THAI,		FALSE },
 	{ N_("_Thai (Windows-874)"),                "windows-874",           LG_THAI,		FALSE },
-#endif	
 	{ N_("Turkish (_IBM-857)"),                 "IBM857",                LG_TURKISH,	FALSE },
 	{ N_("Turkish (I_SO-8859-9)"),              "ISO-8859-9",            LG_TURKISH,	FALSE },
 	{ N_("Turkish (_MacTurkish)"),              "x-mac-turkish",         LG_TURKISH,	FALSE },
 	{ N_("Turkish (_Windows-1254)"),            "windows-1254",          LG_TURKISH,	FALSE },
 	{ N_("Unicode (UTF-_8)"),                   "UTF-8",                 LG_UNICODE,	FALSE },
-	{ N_("Unicode (UTF-_7)"),                   "UTF-7",                 LG_UNICODE,	FALSE },
 	{ N_("Cyrillic/Ukrainian (_KOI8-U)"),       "KOI8-U",                LG_UKRAINIAN,	FALSE },
 	{ N_("Cyrillic/Ukrainian (Mac_Ukrainian)"), "x-mac-ukrainian",       LG_UKRAINIAN,	FALSE },
 	{ N_("Vietnamese (_TCVN)"),                 "x-viet-tcvn5712",       LG_VIETNAMESE,	FALSE },
@@ -142,7 +136,7 @@ encoding_entries [] =
 	 */
 	{ N_("English (_US-ASCII)"),                "us-ascii",              0,			FALSE },
 	{ N_("Unicode (UTF-_16 BE)"),               "UTF-16BE",              0,			FALSE },
-	{ N_("Unicode (UTF-1_6 LE)"),               "UTF-16LE",              0,			FALSE},
+	{ N_("Unicode (UTF-1_6 LE)"),               "UTF-16LE",              0,			FALSE },
 	{ N_("Unicode (UTF-_32 BE)"),               "UTF-32BE",              0,			FALSE },
 	{ N_("Unicode (UTF-3_2 LE)"),               "UTF-32LE",              0,			FALSE },
 
@@ -177,9 +171,9 @@ static GObjectClass *parent_class = NULL;
 GType
 ephy_encodings_get_type (void)
 {
-	static GType ephy_encodings_type = 0;
+	static GType type = 0;
 
-	if (ephy_encodings_type == 0)
+	if (G_UNLIKELY (type == 0))
 	{
 		static const GTypeInfo our_info =
 		{
@@ -194,12 +188,12 @@ ephy_encodings_get_type (void)
 			(GInstanceInitFunc) ephy_encodings_init
 		};
 
-		ephy_encodings_type = g_type_register_static (G_TYPE_OBJECT,
-							      "EphyEncodings",
-							       &our_info, 0);
+		type = g_type_register_static (G_TYPE_OBJECT,
+					       "EphyEncodings",
+					        &our_info, 0);
 	}
 
-	return ephy_encodings_type;
+	return type;
 }
 
 static void
@@ -235,6 +229,35 @@ ephy_encodings_class_init (EphyEncodingsClass *klass)
 	g_type_class_add_private (object_class, sizeof (EphyEncodingsPrivate));
 }
 
+/* copied from egg-toolbar-editor.c */
+static char *
+elide_underscores (const char *original)
+{
+	char *q, *result;
+	const char *p;
+	gboolean last_underscore;
+
+	q = result = g_malloc (strlen (original) + 1);
+	last_underscore = FALSE;
+
+	for (p = original; *p; p++)
+	{
+		if (!last_underscore && *p == '_')
+		{
+			last_underscore = TRUE;
+		}
+		else
+		{
+			last_underscore = FALSE;
+			*q++ = *p;
+		}
+	}
+
+	*q = '\0';
+
+	return result;
+}
+
 static EphyNode *
 add_encoding (EphyEncodings *encodings,
 	      const char *title,
@@ -253,7 +276,7 @@ add_encoding (EphyEncodings *encodings,
 	ephy_node_set_property (node, EPHY_NODE_ENCODING_PROP_TITLE, &value);
 	g_value_unset (&value);
 
-	elided = ephy_string_elide_underscores (title);
+	elided = elide_underscores (title);
 	normalised = g_utf8_normalize (elided, -1, G_NORMALIZE_DEFAULT);
 
 	g_value_init (&value, G_TYPE_STRING);
@@ -451,10 +474,6 @@ ephy_encodings_init (EphyEncodings *encodings)
 	encodings->priv->encodings = ephy_node_new_with_id (db, ENCODINGS_NODE_ID);
 	encodings->priv->detectors = ephy_node_new_with_id (db, DETECTORS_NODE_ID);
 
-	ephy_node_ref (encodings->priv->root);
-	ephy_node_ref (encodings->priv->encodings);
-	ephy_node_ref (encodings->priv->detectors);
-
 	/* now fill the db */
 	for (i = 0; i < n_encoding_entries; i++)
 	{
@@ -491,30 +510,6 @@ ephy_encodings_init (EphyEncodings *encodings)
 	g_slist_free (list);
 }
 
-void
-ephy_encoding_info_free (EphyEncodingInfo *info)
-{
-	if (info)
-	{
-		g_free (info->encoding);
-		g_free (info->hint_encoding);
-		g_free (info->parent_encoding);
-		g_free (info->prev_doc_encoding);
-		g_free (info->forced_encoding);
-		g_free (info->default_encoding);
-		g_free (info);
-	}
-}
-
-gboolean
-ephy_encoding_info_is_automatic (EphyEncodingInfo *info)
-{
-	g_return_val_if_fail (info != NULL, FALSE);
-
-	return (info->encoding_source < EMBED_ENCODING_PARENT_FORCED)
-		&& (info->forced_encoding == NULL || info->forced_encoding[0] == '\0');
-}
-
 EphyEncodings *
 ephy_encodings_new (void)
 {
