@@ -15,14 +15,13 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-history.c,v 1.49 2004/10/23 16:46:46 chpe Exp $
+ *  $Id: ephy-history.c,v 1.53 2004/12/02 15:16:41 chpe Exp $
  */
 
-#ifdef HAVE_CONFIG_H
 #include "config.h"
-#endif
 
 #include "ephy-history.h"
+#include "ephy-marshal.h"
 #include "ephy-file-helpers.h"
 #include "ephy-debug.h"
 #include "ephy-node-db.h"
@@ -72,6 +71,7 @@ enum
 {
 	VISITED,
 	CLEARED,
+	REDIRECT,
         LAST_SIGNAL
 };
 
@@ -199,7 +199,19 @@ ephy_history_class_init (EphyHistoryClass *klass)
                               G_TYPE_NONE,
                               0);
 
-	g_type_class_add_private (object_class, sizeof(EphyHistoryPrivate));
+	signals[REDIRECT] =
+                g_signal_new ("redirect",
+                              G_OBJECT_CLASS_TYPE (object_class),
+                              G_SIGNAL_RUN_FIRST,
+                              G_STRUCT_OFFSET (EphyHistoryClass, redirect),
+                              NULL, NULL,
+                              ephy_marshal_VOID__STRING_STRING,
+                              G_TYPE_NONE,
+                              2,
+			      G_TYPE_STRING,
+			      G_TYPE_STRING);
+
+	g_type_class_add_private (object_class, sizeof (EphyHistoryPrivate));
 }
 
 static gboolean
@@ -231,7 +243,7 @@ remove_obsolete_pages (EphyHistory *eb)
         g_date_set_time (&current_date, time (NULL));
 
 	children = ephy_node_get_children (eb->priv->pages);
-	for (i = children->len -1; i >= 0; i--)
+	for (i = (int) children->len - 1; i >= 0; i--)
 	{
 		EphyNode *kid;
 
@@ -435,6 +447,24 @@ page_removed_from_host_cb (EphyNode *node,
 	}
 }
 
+static void
+remove_pages_from_host_cb (EphyNode *host,
+			   EphyHistory *eh)
+{
+	GPtrArray *children;
+	EphyNode *site;
+	int i;
+
+	children = ephy_node_get_children (host);
+
+	for (i = (int) children->len - 1; i >= 0; i--)
+	{
+		site = g_ptr_array_index (children, i);
+
+		ephy_node_unref (site);
+	}
+}
+
 static void
 connect_page_removed_from_host (char *url,
                                 EphyNode *node,
@@ -446,6 +476,10 @@ connect_page_removed_from_host (char *url,
 					 EPHY_NODE_CHILD_REMOVED,
 				         (EphyNodeCallback) page_removed_from_host_cb,
 					 G_OBJECT (eb));
+	ephy_node_signal_connect_object (node,
+					 EPHY_NODE_DESTROY,
+					 (EphyNodeCallback) remove_pages_from_host_cb,
+					 G_OBJECT (eb));
 }
 
 static void
@@ -706,6 +740,10 @@ ephy_history_get_host (EphyHistory *eh, const char *url)
 						 EPHY_NODE_CHILD_REMOVED,
 					         (EphyNodeCallback) page_removed_from_host_cb,
 						 G_OBJECT (eh));
+		ephy_node_signal_connect_object (host,
+						 EPHY_NODE_DESTROY,
+						 (EphyNodeCallback) remove_pages_from_host_cb,
+						 G_OBJECT (eh));
 
 		g_value_init (&value, G_TYPE_STRING);
 		g_value_set_string (&value, host_name);
