@@ -18,7 +18,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ContentHandler.cpp,v 1.68 2004/11/18 13:50:46 chpe Exp $
+ *  $Id: ContentHandler.cpp,v 1.74 2004/12/18 21:51:47 chpe Exp $
  */
 
 #include "mozilla-config.h"
@@ -28,6 +28,8 @@
 #include <gtk/gtkdialog.h>
 #include <gtk/gtkmessagedialog.h>
 #include <gtk/gtkstock.h>
+#include <gtk/gtkimage.h>
+#include <gtk/gtkbutton.h>
 #include <libgnomevfs/gnome-vfs-mime.h>
 #include <libgnomevfs/gnome-vfs-utils.h>
 #include <glib/gi18n.h>
@@ -147,6 +149,12 @@ NS_IMETHODIMP GContentHandler::PromptForSaveToFile(
 					EPHY_FILE_FILTER_ALL);
 	gtk_file_chooser_set_current_name (GTK_FILE_CHOOSER (dialog), defaultFile.get());
 
+	if (parentWindow)
+	{
+		gtk_window_group_add_window (ephy_gui_ensure_window_group (GTK_WINDOW (parentWindow)),
+					     GTK_WINDOW (dialog));
+	}
+
 	/* FIXME: modal -- mozilla sucks! */
 	do
 	{
@@ -231,9 +239,8 @@ release_cb (GContentHandler *data)
 
 NS_METHOD GContentHandler::MIMEConfirmAction ()
 {
-	GtkWidget *dialog;
-	const char *action_label, *primary, *secondary;
-	//int response;
+	GtkWidget *dialog, *button, *image;
+	const char *action_label;
 
 	nsCOMPtr<nsIDOMWindow> parentDOMWindow = do_GetInterface (mContext);
 	GtkWindow *parentWindow = GTK_WINDOW (EphyUtils::FindGtkParent(parentDOMWindow));
@@ -244,39 +251,53 @@ NS_METHOD GContentHandler::MIMEConfirmAction ()
 
 	if (mPermission == EPHY_MIME_PERMISSION_UNSAFE && mHelperApp)
 	{
-		primary = _("Download the unsafe file?");
-		secondary = _("This type of file could potentially damage "
-			      "your documents or invade your privacy. "
-			      "It's not safe to open it directly. "
-			      "You can save it instead.");
+		dialog = gtk_message_dialog_new
+			(parentWindow, GTK_DIALOG_DESTROY_WITH_PARENT,
+			 GTK_MESSAGE_WARNING, GTK_BUTTONS_NONE,
+			 _("Download the unsafe file?"));
+		gtk_message_dialog_format_secondary_text
+			(GTK_MESSAGE_DIALOG (dialog),
+			 _("This type of file could potentially damage "
+			    "your documents or invade your privacy. "
+			    "It's not safe to open it directly. "
+			    "You can save it instead."));
 	}
-	else if (mAction == CONTENT_ACTION_OPEN_TMP)
+	else if (mAction == CONTENT_ACTION_OPEN_TMP && mHelperApp)
 	{
-		primary = _("Open the file in another application?");
-		secondary = _("It's not possible to view this file type "
-			      "directly in the browser. You can open it with "
-			      "another application or save it.");
+		dialog = gtk_message_dialog_new
+			(parentWindow, GTK_DIALOG_DESTROY_WITH_PARENT,
+			 GTK_MESSAGE_WARNING, GTK_BUTTONS_NONE,
+			 /* translators: %s is the name of the application */
+			 _("Open this file with \"%s\"?"),
+			 mHelperApp->name);
+		gtk_message_dialog_format_secondary_markup
+			(GTK_MESSAGE_DIALOG (dialog),
+			 /* translators: %s is the name of the application */
+			 _("It's not possible to view this file type "
+			   "directly in the browser. You can open it with "
+			   "\"%s\" or save it."),
+			   mHelperApp->name);
 	}
 	else
 	{
-		primary = _("Download the file?");
-		secondary = _("It's not possible to view this file because "
-			      "there is no application installed that can open"
-			      " it. You can save it instead.");
+		dialog = gtk_message_dialog_new
+			(parentWindow, GTK_DIALOG_DESTROY_WITH_PARENT,
+			 GTK_MESSAGE_WARNING, GTK_BUTTONS_NONE,
+			 _("Download the file?"));
+		gtk_message_dialog_format_secondary_text
+			(GTK_MESSAGE_DIALOG (dialog),
+			 _("It's not possible to view this file because "
+			   "there is no application installed that can open"
+			   " it. You can save it instead."));
 	}
 
-	dialog = gtk_message_dialog_new
-		(parentWindow,
-		 GTK_DIALOG_DESTROY_WITH_PARENT,
-		 GTK_MESSAGE_WARNING,
-		 GTK_BUTTONS_NONE,	
-		 primary);
+	button = gtk_button_new_with_label (_("_Save As..."));
+	image = gtk_image_new_from_stock (GTK_STOCK_SAVE_AS, GTK_ICON_SIZE_BUTTON);
+	gtk_button_set_image (GTK_BUTTON (button), image);
+	gtk_widget_show (image);
+	gtk_widget_show (button);
+	gtk_dialog_add_action_widget (GTK_DIALOG (dialog), button, CONTENT_ACTION_SAVEAS);
 
-	gtk_message_dialog_format_secondary_text
-		(GTK_MESSAGE_DIALOG (dialog), secondary);
-
-	gtk_dialog_add_button (GTK_DIALOG (dialog),
-			       _("_Save As..."), CONTENT_ACTION_SAVEAS);
 	gtk_dialog_add_button (GTK_DIALOG (dialog),
 			       GTK_STOCK_CANCEL, CONTENT_ACTION_NONE);
 	gtk_dialog_add_button (GTK_DIALOG (dialog),
@@ -343,8 +364,7 @@ NS_METHOD GContentHandler::MIMEDoAction (void)
 	mLauncher->GetMIMEInfo(getter_AddRefs(mimeInfo));
 	NS_ENSURE_TRUE (mimeInfo, NS_ERROR_FAILURE);
 
-	if (mAction == CONTENT_ACTION_OPEN ||
-	    mAction == CONTENT_ACTION_OPEN_TMP	)
+	if (mAction == CONTENT_ACTION_OPEN)
 	{
 		nsEmbedString desc;
 
