@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: EphyBrowser.cpp,v 1.68 2004/11/19 20:16:45 chpe Exp $
+ *  $Id: EphyBrowser.cpp,v 1.70 2004/12/19 13:43:21 chpe Exp $
  */
 
 #include "mozilla-config.h"
@@ -73,8 +73,11 @@
 #include "nsIScriptSecurityManager.h"
 #include "nsIServiceManager.h"
 #include "nsIInterfaceRequestor.h"
+#include "nsIDOMHTMLDocument.h"
+#include "nsIDOMXMLDocument.h"
 
 #ifdef ALLOW_PRIVATE_API
+#include "nsIImageDocument.h"
 /* not frozen yet */
 #include "nsIContentPolicy.h"
 /* will never be frozen */
@@ -1129,3 +1132,33 @@ EphyBrowser::ShowCertificate ()
 	return NS_OK;
 #endif
 }
+
+EmbedDocumentType
+EphyBrowser::GetDocumentType ()
+{
+  EmbedDocumentType type = EMBED_DOCUMENT_OTHER;
+
+  nsresult rv;
+  nsCOMPtr<nsIDOMDocument> domDoc;
+  rv = GetDocument (getter_AddRefs (domDoc));
+  NS_ENSURE_SUCCESS (rv, type);
+
+  nsCOMPtr<nsIDOMHTMLDocument> htmlDoc (do_QueryInterface (domDoc));
+  nsCOMPtr<nsIDOMXMLDocument> xmlDoc (do_QueryInterface (domDoc));
+  nsCOMPtr<nsIImageDocument> imgDoc (do_QueryInterface (domDoc));
+
+  if (xmlDoc)
+    {
+      type = EMBED_DOCUMENT_XML;
+    }
+  else if (imgDoc)
+    {
+      type = EMBED_DOCUMENT_IMAGE;
+    }
+  else if (htmlDoc)
+    {
+      type = EMBED_DOCUMENT_HTML;
+    }
+
+  return type;
+}
