@@ -15,12 +15,12 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: mozilla-embed-persist.cpp,v 1.38 2004/05/15 18:04:56 chpe Exp $
+ *  $Id: mozilla-embed-persist.cpp,v 1.44 2004/11/02 20:56:55 chpe Exp $
  */
 
-#ifdef HAVE_CONFIG_H
+#include "mozilla-config.h"
+
 #include "config.h"
-#endif
 
 #include "mozilla-embed-persist.h"
 #include "mozilla-embed.h"
@@ -29,6 +29,7 @@
 #include "EphyBrowser.h"
 #include "EphyHeaderSniffer.h"
 #include "MozDownload.h"
+#include "EphyUtils.h"
 
 #include <stddef.h>
 
@@ -36,13 +37,9 @@
 #include <nsCWebBrowserPersist.h>
 #include <nsIHistoryEntry.h>
 #include <nsISHEntry.h>
-
-#ifdef ALLOW_PRIVATE_STRINGS
-#include <nsString.h>
-#include <nsNetUtil.h>
-#include <nsIDocumentEncoder.h>
-#include <nsIDocument.h>
-#endif
+#include <nsIDOMSerializer.h>
+#include <nsIIOService.h>
+#include <nsNetCID.h>
 
 static void
 mozilla_embed_persist_class_init (MozillaEmbedPersistClass *klass);
@@ -63,9 +60,9 @@ static GObjectClass *parent_class = NULL;
 GType
 mozilla_embed_persist_get_type (void)
 {
-       static GType mozilla_embed_persist_type = 0;
+       static GType type = 0;
 
-        if (mozilla_embed_persist_type == 0)
+        if (G_UNLIKELY (type == 0))
         {
                 static const GTypeInfo our_info =
                 {
@@ -80,19 +77,19 @@ mozilla_embed_persist_get_type (void)
                         (GInstanceInitFunc) mozilla_embed_persist_init
                 };
 
-                mozilla_embed_persist_type = 
-				g_type_register_static (EPHY_TYPE_EMBED_PERSIST,
-                                                        "MozillaEmbedPersist",
-                                                        &our_info, (GTypeFlags)0);
+                type = g_type_register_static (EPHY_TYPE_EMBED_PERSIST,
+					       "MozillaEmbedPersist",
+					       &our_info, (GTypeFlags) 0);
         }
 
-        return mozilla_embed_persist_type;
+        return type;
 }
 
 static void
 mozilla_embed_persist_init (MozillaEmbedPersist *persist)
 {
         persist->priv = MOZILLA_EMBED_PERSIST_GET_PRIVATE (persist);
+
       	persist->priv->mPersist = do_CreateInstance (NS_WEBBROWSERPERSIST_CONTRACTID);
 }
 
@@ -142,6 +139,9 @@ impl_save (EphyEmbedPersist *persist)
 	long max_size;
 	EphyEmbed *embed;
 	EmbedPersistFlags flags;
+	EphyEmbedSingle *single;
+
+	single = EPHY_EMBED_SINGLE (ephy_embed_shell_get_embed_single (embed_shell));
 
 	g_object_ref (persist);
 	
@@ -176,12 +176,12 @@ impl_save (EphyEmbedPersist *persist)
 	if (tmp_filename == NULL) return FALSE;
 
 	nsCOMPtr<nsILocalFile> tmpFile = do_CreateInstance (NS_LOCAL_FILE_CONTRACTID);
-	tmpFile->InitWithNativePath (nsDependentCString (tmp_filename));
+	tmpFile->InitWithNativePath (nsEmbedCString (tmp_filename));
 	g_free (tmp_filename);
 
 	/* Get the uri to save to */
 	nsCOMPtr<nsIURI> inURI;
-	nsCAutoString sURI;
+	nsEmbedCString sURI;
 	if (uri)
 	{
 		sURI.Assign (uri);
@@ -191,8 +191,9 @@ impl_save (EphyEmbedPersist *persist)
 		rv = browser->GetDocumentUrl (sURI);
 		NS_ENSURE_SUCCESS (rv, FALSE);
 	}
-      	NS_NewURI(getter_AddRefs(inURI), sURI);
-	if (!inURI) return FALSE;
+
+	rv = EphyUtils::NewURI (getter_AddRefs(inURI), sURI);
+	NS_ENSURE_SUCCESS (rv, FALSE);
 
 	/* Get post data */
 	nsCOMPtr<nsIInputStream> postData;
@@ -251,7 +252,7 @@ impl_save (EphyEmbedPersist *persist)
 
 		EphyHeaderSniffer* sniffer = new EphyHeaderSniffer
 			(webPersist, MOZILLA_EMBED_PERSIST (persist),
-			 tmpFile, inURI, DOMDocument, postData);
+			 tmpFile, inURI, DOMDocument, postData, single);
 		if (!sniffer) return FALSE;
  
 		webPersist->SetProgressListener(sniffer);
@@ -262,7 +263,7 @@ impl_save (EphyEmbedPersist *persist)
 	{
 		/* Filename to save to */
 		nsCOMPtr<nsILocalFile> destFile;
-		NS_NewNativeLocalFile (nsDependentCString(filename),
+		NS_NewNativeLocalFile (nsEmbedCString(filename),
 				       PR_TRUE, getter_AddRefs(destFile));
 	        NS_ENSURE_TRUE (destFile, FALSE);
 
@@ -309,19 +310,20 @@ impl_to_string (EphyEmbedPersist *persist)
 	}
 	if (NS_FAILED(rv) || !DOMDocument) return NULL;
 
-	nsCOMPtr<nsIDocument> doc = do_QueryInterface(DOMDocument);
-	if(!doc) return NULL;
+	nsCOMPtr<nsIDOMNode> node = do_QueryInterface(DOMDocument);
+	if (!node) return NULL;
 
-	nsCOMPtr<nsIDocumentEncoder> encoder = do_CreateInstance(NS_DOC_ENCODER_CONTRACTID_BASE "text/html");
-	NS_ENSURE_SUCCESS(rv, NULL);
+	nsCOMPtr<nsIDOMSerializer> serializer;
+	serializer = do_CreateInstance(NS_XMLSERIALIZER_CONTRACTID, &rv);
+	NS_ENSURE_SUCCESS (rv, FALSE);
 
-	rv = encoder->Init(doc, NS_LITERAL_STRING("text/html"), nsIDocumentEncoder::OutputAbsoluteLinks);
-	NS_ENSURE_SUCCESS(rv, NULL);
+	nsEmbedString outString;
+	serializer->SerializeToString(node, outString);
 
-	nsAutoString aOutputString;
-	encoder->EncodeToString(aOutputString);
+	nsEmbedCString cOutString;
+	NS_UTF16ToCString (outString, NS_CSTRING_ENCODING_UTF8, cOutString);
 
-	return g_strdup (NS_ConvertUTF16toUTF8(aOutputString).get());
+	return g_strdup (cOutString.get());
 }
 
 static GObject *
