@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-gui.c,v 1.29 2004/11/09 20:32:01 chpe Exp $
+ *  $Id: ephy-gui.c,v 1.32 2004/12/19 11:00:18 chpe Exp $
  */
 
 #include "config.h"
@@ -113,14 +113,11 @@ ephy_gui_menu_position_under_widget (GtkMenu   *menu,
 {
 	GtkWidget *w = GTK_WIDGET (user_data);
 	GtkRequisition requisition;
-	gboolean rtl;
-
-	rtl = (gtk_widget_get_direction (w) == GTK_TEXT_DIR_RTL);
 
 	gdk_window_get_origin (w->window, x, y);
 	gtk_widget_size_request (GTK_WIDGET (menu), &requisition);
 
-	if (rtl)
+	if (gtk_widget_get_direction (w) == GTK_TEXT_DIR_RTL)
 	{
 		*x += w->allocation.x + w->allocation.width - requisition.width;
 	}
@@ -134,8 +131,62 @@ ephy_gui_menu_position_under_widget (GtkMenu   *menu,
 	ephy_gui_sanitise_popup_position (menu, w, x, y);
 }
 
+void
+ephy_gui_menu_position_on_panel (GtkMenu *menu,
+				 gint      *x,
+				 gint      *y,
+				 gboolean  *push_in,
+				 gpointer  user_data)
+{
+	GtkWidget *widget = GTK_WIDGET (user_data);
+	GtkRequisition requisition;
+	GdkScreen *screen;
+
+	screen = gtk_widget_get_screen (widget);
+
+	gdk_window_get_origin (widget->window, x, y);
+	gtk_widget_size_request (GTK_WIDGET (menu), &requisition);
+
+	if (GTK_WIDGET_NO_WINDOW (widget))
+	{
+		*x += widget->allocation.x;
+		*y += widget->allocation.y;
+	}
+
+	/* FIXME: Adapt to vertical panels, but egg_tray_icon_get_orientation doesn't seem to work */
+	if (*y > gdk_screen_get_height (screen) / 2)
+	{
+		*y -= requisition.height;
+	}
+	else
+	{
+		*y += widget->allocation.height;
+	}
+
+	*push_in = FALSE;
+
+	ephy_gui_sanitise_popup_position (menu, widget, x, y);
+}
+
+GtkWindowGroup *
+ephy_gui_ensure_window_group (GtkWindow *window)
+{
+	GtkWindowGroup *group;
+
+	group = window->group;
+	if (group == NULL)
+	{
+		group = gtk_window_group_new ();
+		gtk_window_group_add_window (group, window);
+		g_object_unref (group);
+	}
+
+	return group;
+}
+
 gboolean
-ephy_gui_confirm_overwrite_file (GtkWidget *parent, const char *filename)
+ephy_gui_confirm_overwrite_file (GtkWidget *parent,
+				 const char *filename)
 {
 	GtkWidget *dialog;
 	char *display_name;
@@ -152,7 +203,7 @@ ephy_gui_confirm_overwrite_file (GtkWidget *parent, const char *filename)
 
 	dialog = gtk_message_dialog_new
 		(parent ? GTK_WINDOW (parent) : NULL,
-		 GTK_DIALOG_MODAL,
+		 GTK_DIALOG_DESTROY_WITH_PARENT,
 		 GTK_MESSAGE_WARNING,
 		 GTK_BUTTONS_CANCEL,
 		 _("A file %s already exists."), display_name);
@@ -170,6 +221,12 @@ ephy_gui_confirm_overwrite_file (GtkWidget *parent, const char *filename)
 
 	gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_CANCEL);
 
+	if (parent != NULL)
+	{
+		gtk_window_group_add_window (ephy_gui_ensure_window_group (GTK_WINDOW (parent)),
+					     GTK_WINDOW (dialog));
+	}
+
 	retval = (gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_ACCEPT);
 
 	gtk_widget_destroy (dialog);
