@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-gui.h,v 1.13 2004/11/07 20:26:57 chpe Exp $
+ *  $Id: ephy-gui.h,v 1.15 2004/12/18 21:51:47 chpe Exp $
  */
 
 #ifndef EPHY_GUI_H
@@ -47,6 +47,14 @@ void		ephy_gui_menu_position_under_widget	 (GtkMenu   *menu,
 							  gboolean  *push_in,
 							  gpointer  user_data);
 
+void		ephy_gui_menu_position_on_panel		 (GtkMenu *menu,
+							  gint      *x,
+							  gint      *y,
+							  gboolean  *push_in,
+							  gpointer  user_data);
+
+GtkWindowGroup *ephy_gui_ensure_window_group		 (GtkWindow *window);
+
 gboolean	ephy_gui_is_middle_click		 (void);
 
 gboolean	ephy_gui_select_row_by_key		 (GtkTreeView *treeview,
