@@ -6,7 +6,7 @@
 
 G_BEGIN_DECLS
 
-/* INT:STRING (./ephy-marshal.list:1) */
+/* INT:STRING (../../lib/ephy-marshal.list:1) */
 extern void ephy_marshal_INT__STRING (GClosure     *closure,
                                       GValue       *return_value,
                                       guint         n_param_values,
@@ -14,7 +14,7 @@ extern void ephy_marshal_INT__STRING (GClosure     *closure,
                                       gpointer      invocation_hint,
                                       gpointer      marshal_data);
 
-/* BOOLEAN:OBJECT (./ephy-marshal.list:2) */
+/* BOOLEAN:OBJECT (../../lib/ephy-marshal.list:2) */
 extern void ephy_marshal_BOOLEAN__OBJECT (GClosure     *closure,
                                           GValue       *return_value,
                                           guint         n_param_values,
@@ -22,7 +22,7 @@ extern void ephy_marshal_BOOLEAN__OBJECT (GClosure     *closure,
                                           gpointer      invocation_hint,
                                           gpointer      marshal_data);
 
-/* BOOLEAN:STRING,STRING (./ephy-marshal.list:3) */
+/* BOOLEAN:STRING,STRING (../../lib/ephy-marshal.list:3) */
 extern void ephy_marshal_BOOLEAN__STRING_STRING (GClosure     *closure,
                                                  GValue       *return_value,
                                                  guint         n_param_values,
@@ -30,7 +30,26 @@ extern void ephy_marshal_BOOLEAN__STRING_STRING (GClosure     *closure,
                                                  gpointer      invocation_hint,
                                                  gpointer      marshal_data);
 
-/* VOID:INT,INT (./ephy-marshal.list:4) */
+/* BOOLEAN:VOID (../../lib/ephy-marshal.list:4) */
+extern void ephy_marshal_BOOLEAN__VOID (GClosure     *closure,
+                                        GValue       *return_value,
+                                        guint         n_param_values,
+                                        const GValue *param_values,
+                                        gpointer      invocation_hint,
+                                        gpointer      marshal_data);
+
+/* VOID:ENUM (../../lib/ephy-marshal.list:5) */
+#define ephy_marshal_VOID__ENUM	g_cclosure_marshal_VOID__ENUM
+
+/* VOID:ENUM,INT,BOOLEAN (../../lib/ephy-marshal.list:6) */
+extern void ephy_marshal_VOID__ENUM_INT_BOOLEAN (GClosure     *closure,
+                                                 GValue       *return_value,
+                                                 guint         n_param_values,
+                                                 const GValue *param_values,
+                                                 gpointer      invocation_hint,
+                                                 gpointer      marshal_data);
+
+/* VOID:INT,INT (../../lib/ephy-marshal.list:7) */
 extern void ephy_marshal_VOID__INT_INT (GClosure     *closure,
                                         GValue       *return_value,
                                         guint         n_param_values,
@@ -38,7 +57,7 @@ extern void ephy_marshal_VOID__INT_INT (GClosure     *closure,
                                         gpointer      invocation_hint,
                                         gpointer      marshal_data);
 
-/* VOID:POINTER,INT (./ephy-marshal.list:5) */
+/* VOID:POINTER,INT (../../lib/ephy-marshal.list:8) */
 extern void ephy_marshal_VOID__POINTER_INT (GClosure     *closure,
                                             GValue       *return_value,
                                             guint         n_param_values,
@@ -46,7 +65,7 @@ extern void ephy_marshal_VOID__POINTER_INT (GClosure     *closure,
                                             gpointer      invocation_hint,
                                             gpointer      marshal_data);
 
-/* VOID:POINTER,BOOLEAN (./ephy-marshal.list:6) */
+/* VOID:POINTER,BOOLEAN (../../lib/ephy-marshal.list:9) */
 extern void ephy_marshal_VOID__POINTER_BOOLEAN (GClosure     *closure,
                                                 GValue       *return_value,
                                                 guint         n_param_values,
@@ -54,7 +73,7 @@ extern void ephy_marshal_VOID__POINTER_BOOLEAN (GClosure     *closure,
                                                 gpointer      invocation_hint,
                                                 gpointer      marshal_data);
 
-/* VOID:POINTER,POINTER (./ephy-marshal.list:7) */
+/* VOID:POINTER,POINTER (../../lib/ephy-marshal.list:10) */
 extern void ephy_marshal_VOID__POINTER_POINTER (GClosure     *closure,
                                                 GValue       *return_value,
                                                 guint         n_param_values,
@@ -62,7 +81,7 @@ extern void ephy_marshal_VOID__POINTER_POINTER (GClosure     *closure,
                                                 gpointer      invocation_hint,
                                                 gpointer      marshal_data);
 
-/* VOID:STRING,INT (./ephy-marshal.list:8) */
+/* VOID:STRING,INT (../../lib/ephy-marshal.list:11) */
 extern void ephy_marshal_VOID__STRING_INT (GClosure     *closure,
                                            GValue       *return_value,
                                            guint         n_param_values,
@@ -70,7 +89,7 @@ extern void ephy_marshal_VOID__STRING_INT (GClosure     *closure,
                                            gpointer      invocation_hint,
                                            gpointer      marshal_data);
 
-/* VOID:STRING,INT,INT (./ephy-marshal.list:9) */
+/* VOID:STRING,INT,INT (../../lib/ephy-marshal.list:12) */
 extern void ephy_marshal_VOID__STRING_INT_INT (GClosure     *closure,
                                                GValue       *return_value,
                                                guint         n_param_values,
@@ -78,7 +97,7 @@ extern void ephy_marshal_VOID__STRING_INT_INT (GClosure     *closure,
                                                gpointer      invocation_hint,
                                                gpointer      marshal_data);
 
-/* VOID:STRING,STRING (./ephy-marshal.list:10) */
+/* VOID:STRING,STRING (../../lib/ephy-marshal.list:13) */
 extern void ephy_marshal_VOID__STRING_STRING (GClosure     *closure,
                                               GValue       *return_value,
                                               guint         n_param_values,
@@ -86,7 +105,7 @@ extern void ephy_marshal_VOID__STRING_STRING (GClosure     *closure,
                                               gpointer      invocation_hint,
                                               gpointer      marshal_data);
 
-/* VOID:STRING,BOOLEAN (./ephy-marshal.list:11) */
+/* VOID:STRING,BOOLEAN (../../lib/ephy-marshal.list:14) */
 extern void ephy_marshal_VOID__STRING_BOOLEAN (GClosure     *closure,
                                                GValue       *return_value,
                                                guint         n_param_values,
