@@ -17,8 +17,11 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
+ *  $Id: ephy-state.c,v 1.30 2004/11/02 20:57:20 chpe Exp $
  */
 
+#include "config.h"
+
 #include "ephy-state.h"
 #include "ephy-file-helpers.h"
 #include "ephy-node-db.h"
@@ -119,8 +122,7 @@ ensure_states (void)
 static void
 ephy_state_window_set_size (GtkWidget *window, EphyNode *node)
 {
-	int width;
-	int height;
+	int width, height, w = -1, h = -1;
 	gboolean maximize, size;
 
 	width = ephy_node_get_property_int (node, EPHY_NODE_STATE_PROP_WIDTH);
@@ -128,7 +130,8 @@ ephy_state_window_set_size (GtkWidget *window, EphyNode *node)
 	maximize = ephy_node_get_property_boolean (node, EPHY_NODE_STATE_PROP_MAXIMIZE);
 	size = ephy_node_get_property_boolean (node, EPHY_NODE_STATE_PROP_SIZE);
 
-	if (size)
+	gtk_window_get_default_size (GTK_WINDOW (window), &w, &h);
+	if (size && w == -1 && h == -1)
 	{
 		GdkScreen *screen;
 		int screen_width, screen_height;
@@ -313,6 +316,7 @@ static EphyNode *
 create_window_node (const char *name,
 		    int default_width,
 		    int default_height,
+		    gboolean maximize,
 		    EphyStateWindowFlags flags)
 {
 	EphyNode *node;
@@ -328,7 +332,7 @@ create_window_node (const char *name,
 	g_value_unset (&value);
 
 	g_value_init (&value, G_TYPE_BOOLEAN);
-	g_value_set_boolean (&value, FALSE);
+	g_value_set_boolean (&value, maximize);
 	ephy_node_set_property (node, EPHY_NODE_STATE_PROP_MAXIMIZE,
 			        &value);
 	g_value_unset (&value);
@@ -362,6 +366,7 @@ ephy_state_add_window (GtkWidget *window,
 		       const char *name,
 		       int default_width,
 		       int default_height,
+		       gboolean maximize,
 		       EphyStateWindowFlags flags)
 {
 	EphyNode *node;
@@ -371,7 +376,8 @@ ephy_state_add_window (GtkWidget *window,
 	node = find_by_name (name);
 	if (node == NULL)
 	{
-		node = create_window_node (name, default_width, default_height, flags);
+		node = create_window_node (name, default_width, default_height,
+					   maximize, flags);
 	}
 
 	ephy_state_window_set_size (window, node);
