@@ -15,12 +15,10 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-node-view.c,v 1.51 2004/10/27 19:54:57 chpe Exp $
+ *  $Id: ephy-node-view.c,v 1.54 2004/12/13 18:58:58 chpe Exp $
  */
 
-#ifdef HAVE_CONFIG_H
 #include "config.h"
-#endif
 
 #include <gtk/gtktreeselection.h>
 #include <gtk/gtktreeviewcolumn.h>
@@ -38,8 +36,7 @@
 #include "ephy-dnd.h"
 #include "ephy-gui.h"
 #include "ephy-marshal.h"
-#include "ephy-string.h"
-#include "string.h"
+#include <string.h>
 
 static void ephy_node_view_class_init (EphyNodeViewClass *klass);
 static void ephy_node_view_init (EphyNodeView *view);
@@ -1583,14 +1580,19 @@ ephy_node_view_popup (EphyNodeView *view, GtkWidget *menu)
 	{
 		if (event->type == GDK_KEY_PRESS)
 		{
+			GdkEventKey *key = (GdkEventKey *) event;
+
 			gtk_menu_popup (GTK_MENU (menu), NULL, NULL,
 					ephy_gui_menu_position_tree_selection,
-					view, 2, gtk_get_current_event_time ());
+					view, 0, key->time);
+			gtk_menu_shell_select_first (GTK_MENU_SHELL (menu), FALSE);
 		}
-		else
+		else if (event->type == GDK_BUTTON_PRESS)
 		{
+			GdkEventButton *button = (GdkEventButton *) event;
+
 			gtk_menu_popup (GTK_MENU (menu), NULL, NULL, NULL,
-					NULL, 2, gtk_get_current_event_time ());
+					NULL, button->button, button->time);
 		}
 
 		gdk_event_free (event);
