@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-node-view.h,v 1.11 2004/07/23 10:49:39 marco Exp $
+ *  $Id: ephy-node-view.h,v 1.13 2004/10/27 13:58:55 chpe Exp $
  */
 
 #ifndef __EPHY_NODE_VIEW_H
@@ -69,7 +69,6 @@ typedef struct
 	void (*node_activated)      (EphyNodeView *view, EphyNode *node);
 	void (*node_selected)       (EphyNodeView *view, EphyNode *node);
 	void (*node_dropped)        (EphyNodeView *view, EphyNode *node, GList *uris);
-	void (*show_popup)          (EphyNodeView *view);
 } EphyNodeViewClass;
 
 GType              ephy_node_view_get_type	      (void);
@@ -128,6 +127,9 @@ void		   ephy_node_view_edit		      (EphyNodeView *view,
 
 gboolean	   ephy_node_view_is_target	      (EphyNodeView *view);
 
+void		   ephy_node_view_popup		      (EphyNodeView *view,
+						       GtkWidget *menu);
+
 G_END_DECLS
 
 #endif /* EPHY_NODE_VIEW_H */
