@@ -1,5 +1,4 @@
 /* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 8; tab-width: 8 -*- */
-
 /*
  * Nautilus
  *
@@ -23,45 +22,52 @@
  *
  * This is the header file for the throbber on the location bar
  *
+ * $Id: ephy-spinner.h,v 1.9 2004/07/02 22:05:59 chpe Exp $
  */
 
 #ifndef EPHY_SPINNER_H
 #define EPHY_SPINNER_H
 
 #include <gtk/gtkeventbox.h>
+#include <gtk/gtkenums.h>
 
 G_BEGIN_DECLS
 
-#define EPHY_SPINNER_TYPE		(ephy_spinner_get_type ())
-#define EPHY_SPINNER(obj)		(GTK_CHECK_CAST ((obj), EPHY_SPINNER_TYPE, EphySpinner))
-#define EPHY_SPINNER_CLASS(klass)	(GTK_CHECK_CLASS_CAST ((klass), EPHY_SPINNER_TYPE, EphySpinnerClass))
-#define IS_EPHY_SPINNER(obj)		(GTK_CHECK_TYPE ((obj), EPHY_SPINNER_TYPE))
-#define IS_EPHY_SPINNER_CLASS(klass)    (GTK_CHECK_CLASS_TYPE ((klass), EPHY_SPINNER_TYPE))
+#define EPHY_TYPE_SPINNER		(ephy_spinner_get_type ())
+#define EPHY_SPINNER(o)			(G_TYPE_CHECK_INSTANCE_CAST ((o), EPHY_TYPE_SPINNER, EphySpinner))
+#define EPHY_SPINNER_CLASS(k)		(G_TYPE_CHECK_CLASS_CAST((k), EPHY_TYPE_SPINNER, EphySpinnerClass))
+#define EPHY_IS_SPINNER(o)		(G_TYPE_CHECK_INSTANCE_TYPE ((o), EPHY_TYPE_SPINNER))
+#define EPHY_IS_SPINNER_CLASS(k)	(G_TYPE_CHECK_CLASS_TYPE ((k), EPHY_TYPE_SPINNER))
+#define EPHY_SPINNER_GET_CLASS(o)	(G_TYPE_INSTANCE_GET_CLASS ((o), EPHY_TYPE_SPINNER, EphySpinnerClass))
 
-typedef struct EphySpinnerInfo	EphySpinnerInfo;
+typedef struct EphySpinner		EphySpinner;
+typedef struct EphySpinnerClass		EphySpinnerClass;
+typedef struct EphySpinnerDetails	EphySpinnerDetails;
 
-typedef struct EphySpinner EphySpinner;
-typedef struct EphySpinnerClass EphySpinnerClass;
-typedef struct EphySpinnerDetails EphySpinnerDetails;
-
-struct EphySpinner {
+struct EphySpinner
+{
 	GtkEventBox parent;
+
+	/*< private >*/
 	EphySpinnerDetails *details;
 };
 
-struct EphySpinnerClass {
+struct EphySpinnerClass
+{
 	GtkEventBoxClass parent_class;
 };
 
-GType         ephy_spinner_get_type       (void);
-GtkWidget    *ephy_spinner_new            (void);
-void          ephy_spinner_start          (EphySpinner *throbber);
-void          ephy_spinner_stop           (EphySpinner *throbber);
-void	      ephy_spinner_set_small_mode (EphySpinner *spinner,
-					   gboolean new_mode);
+GType		ephy_spinner_get_type	(void);
+
+GtkWidget      *ephy_spinner_new	(void);
+
+void		ephy_spinner_start	(EphySpinner *throbber);
+
+void		ephy_spinner_stop	(EphySpinner *throbber);
+
+void		ephy_spinner_set_size	(EphySpinner *spinner,
+					 GtkIconSize size);
 
 G_END_DECLS
 
 #endif /* EPHY_SPINNER_H */
-
-
