@@ -15,15 +15,15 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-tree-model-node.c,v 1.14 2004/01/25 20:05:39 chpe Exp $
+ *  $Id: ephy-tree-model-node.c,v 1.20 2004/11/02 20:57:20 chpe Exp $
  */
 
-#include <config.h>
+#include "config.h"
+
 #include <gdk-pixbuf/gdk-pixbuf.h>
 #include <time.h>
 #include <string.h>
 
-#include "ephy-node-filter.h"
 #include "ephy-tree-model-node.h"
 #include "ephy-stock-icons.h"
 #include "ephy-node.h"
@@ -40,8 +40,6 @@ struct EphyTreeModelNodePrivate
 {
 	EphyNode *root;
 
-	EphyNodeFilter *filter;
-
 	GPtrArray *columns;
 	int columns_num;
 
@@ -59,8 +57,7 @@ typedef struct
 enum
 {
 	PROP_0,
-	PROP_ROOT,
-	PROP_FILTER
+	PROP_ROOT
 };
 
 static GObjectClass *parent_class = NULL;
@@ -68,9 +65,9 @@ static GObjectClass *parent_class = NULL;
 GType
 ephy_tree_model_node_get_type (void)
 {
-	static GType ephy_tree_model_node_type = 0;
+	static GType type = 0;
 
-	if (ephy_tree_model_node_type == 0)
+	if (G_UNLIKELY (type == 0))
 	{
 		static const GTypeInfo our_info =
 		{
@@ -92,16 +89,16 @@ ephy_tree_model_node_get_type (void)
 			NULL
 		};
 
-		ephy_tree_model_node_type = g_type_register_static (G_TYPE_OBJECT,
-								  "EphyTreeModelNode",
-								  &our_info, 0);
+		type = g_type_register_static (G_TYPE_OBJECT,
+					       "EphyTreeModelNode",
+					       &our_info, 0);
 
-		g_type_add_interface_static (ephy_tree_model_node_type,
+		g_type_add_interface_static (type,
 					     GTK_TYPE_TREE_MODEL,
 					     &tree_model_info);
 	}
 
-	return ephy_tree_model_node_type;
+	return type;
 }
 
 static void
@@ -174,6 +171,7 @@ ephy_tree_model_node_update_node (EphyTreeModelNode *model,
 static void
 root_child_changed_cb (EphyNode *node,
 		       EphyNode *child,
+		       guint property_id,
 		       EphyTreeModelNode *model)
 {
 	ephy_tree_model_node_update_node (model, child, -1);
@@ -201,23 +199,6 @@ root_destroy_cb (EphyNode *node,
 	 * signals already */
 }
 
-static void
-filter_changed_cb (EphyNodeFilter *filter,
-		   EphyTreeModelNode *model)
-{
-	GPtrArray *kids;
-	int i;
-
-	kids = ephy_node_get_children (model->priv->root);
-
-	for (i = 0; i < kids->len; i++)
-	{
-		ephy_tree_model_node_update_node (model,
-						g_ptr_array_index (kids, i),
-						i);
-	}
-}
-
 static void
 ephy_tree_model_node_set_property (GObject *object,
 			           guint prop_id,
@@ -252,18 +233,6 @@ ephy_tree_model_node_set_property (GObject *object,
 				                 (EphyNodeCallback) root_destroy_cb,
 				                 G_OBJECT (model));
 
-		break;
-	case PROP_FILTER:
-		model->priv->filter = g_value_get_object (value);
-
-		if (model->priv->filter != NULL)
-		{
-			g_signal_connect_object (G_OBJECT (model->priv->filter),
-					         "changed",
-					         G_CALLBACK (filter_changed_cb),
-					         G_OBJECT (model),
-						 0);
-		}
 		break;
 	default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
@@ -284,9 +253,6 @@ ephy_tree_model_node_get_property (GObject *object,
 	case PROP_ROOT:
 		g_value_set_pointer (value, model->priv->root);
 		break;
-	case PROP_FILTER:
-		g_value_set_object (value, model->priv->filter);
-		break;
 	default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
 		break;
@@ -311,13 +277,6 @@ ephy_tree_model_node_class_init (EphyTreeModelNodeClass *klass)
 							      "Root node",
 							      "Root node",
 							      G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY));
-	g_object_class_install_property (object_class,
-					 PROP_FILTER,
-					 g_param_spec_object ("filter",
-							      "Filter object",
-							      "Filter object",
-							      EPHY_TYPE_NODE_FILTER,
-							      G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY));
 
 	g_type_class_add_private (object_class, sizeof (EphyTreeModelNodePrivate));
 }
@@ -328,7 +287,7 @@ ephy_tree_model_node_init (EphyTreeModelNode *model)
 	model->priv = EPHY_TREE_MODEL_NODE_GET_PRIVATE (model);
 	model->priv->stamp = g_random_int ();
 	model->priv->columns = g_ptr_array_new ();
-	model->priv->columns_num = EPHY_TREE_MODEL_NODE_BUILTIN_COLUMNS;
+	model->priv->columns_num = 0;
 }
 
 static void
@@ -343,13 +302,11 @@ ephy_tree_model_node_finalize (GObject *object)
 }
 
 EphyTreeModelNode *
-ephy_tree_model_node_new (EphyNode *root,
-			  EphyNodeFilter *filter)
+ephy_tree_model_node_new (EphyNode *root)
 {
 	EphyTreeModelNode *model;
 
 	model = EPHY_TREE_MODEL_NODE (g_object_new (EPHY_TYPE_TREE_MODEL_NODE,
-						    "filter", filter,
 						    "root", root,
 						    NULL));
 
@@ -413,15 +370,10 @@ static GType
 ephy_tree_model_node_get_column_type (GtkTreeModel *tree_model,
 			              int index)
 {
-	int list_index;
 	EphyTreeModelNodeColData *col;
 	EphyTreeModelNode *model = EPHY_TREE_MODEL_NODE (tree_model);
 
-	if (index == EPHY_TREE_MODEL_NODE_COL_VISIBLE)
-		return G_TYPE_BOOLEAN;
-
-	list_index = index - EPHY_TREE_MODEL_NODE_BUILTIN_COLUMNS;
-	col = g_ptr_array_index (model->priv->columns, list_index);
+	col = g_ptr_array_index (model->priv->columns, index);
 
 	return col->type;
 }
@@ -432,7 +384,6 @@ ephy_tree_model_node_get_value (GtkTreeModel *tree_model,
 			        int column,
 			        GValue *value)
 {
-	int list_index;
 	EphyTreeModelNodeColData *col;
 	EphyTreeModelNode *model = EPHY_TREE_MODEL_NODE (tree_model);
 	EphyNode *node;
@@ -446,47 +397,29 @@ ephy_tree_model_node_get_value (GtkTreeModel *tree_model,
 
 	node = iter->user_data;
 
-	if (column == EPHY_TREE_MODEL_NODE_COL_VISIBLE)
-	{
-		g_value_init (value, G_TYPE_BOOLEAN);
+	col = g_ptr_array_index (model->priv->columns, column);
 
-		if (model->priv->filter != NULL)
+	g_return_if_fail (col != NULL);
+
+	if (col->prop_id >= 0)
+	{
+		if (!ephy_node_get_property (node, col->prop_id, value))
 		{
-			g_value_set_boolean (value,
-					     ephy_node_filter_evaluate (model->priv->filter, node));
-		}
-		else
-		{
-			g_value_set_boolean (value, TRUE);
+			/* make sure to return a valid string anyway */
+			g_value_init (value, col->type);
+			if (col->type == G_TYPE_STRING)
+			{
+				g_value_set_string (value, "");
+			}
 		}
 	}
 	else
 	{
-		list_index = column - EPHY_TREE_MODEL_NODE_BUILTIN_COLUMNS;
-		col = g_ptr_array_index (model->priv->columns, list_index);
-
-		g_return_if_fail (col != NULL);
-
-		if (col->prop_id >= 0)
-		{
-			if (!ephy_node_get_property (node, col->prop_id, value))
-			{
-				/* make sure to return a valid string anyway */
-				g_value_init (value, col->type);
-				if (col->type == G_TYPE_STRING)
-				{
-					g_value_set_string (value, "");
-				}
-			}
-		}
-		else
-		{
-			col->func (node, value, col->user_data);
-		}
+		col->func (node, value, col->user_data);
 	}
 }
 
-static guint
+static GtkTreeModelFlags
 ephy_tree_model_node_get_flags (GtkTreeModel *tree_model)
 {
 	return GTK_TREE_MODEL_ITERS_PERSIST | GTK_TREE_MODEL_LIST_ONLY;
