@@ -16,12 +16,10 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-bookmarks.c,v 1.91 2004/11/01 14:00:05 chpe Exp $
+ *  $Id: ephy-bookmarks.c,v 1.95 2004/12/13 19:04:01 chpe Exp $
  */
 
-#ifdef HAVE_CONFIG_H
 #include "config.h"
-#endif
 
 #include "ephy-bookmarks.h"
 #include "ephy-file-helpers.h"
@@ -42,11 +40,14 @@
 #include <string.h>
 #include <glib/gi18n.h>
 #include <libgnomevfs/gnome-vfs-utils.h>
+#include <gtk/gtkmessagedialog.h>
+#include <gtk/gtkdialog.h>
 
 #define EPHY_BOOKMARKS_XML_ROOT    "ephy_bookmarks"
 #define EPHY_BOOKMARKS_XML_VERSION "1.03"
 #define BOOKMARKS_SAVE_DELAY (3 * 1000)
 #define MAX_FAVORITES_NUM 10
+#define UPDATE_URI_DATA_KEY "updated-uri"
 
 #define EPHY_BOOKMARKS_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object), EPHY_TYPE_BOOKMARKS, EphyBookmarksPrivate))
 
@@ -458,7 +459,7 @@ clear_favorites (EphyBookmarks *bookmarks)
 
 	node = bookmarks->priv->favorites;
 	children = ephy_node_get_children (node);
-	for (i = children->len - 1; i >= 0; i--)
+	for (i = (int) children->len - 1; i >= 0; i--)
 	{
 		EphyNode *kid;
 
@@ -478,6 +479,89 @@ history_cleared_cb (EphyHistory *history, EphyBookmarks *bookmarks)
 	clear_favorites (bookmarks);
 }
 
+static void
+update_bookmark_response_cb (GtkWidget *dialog,
+			     int response,
+			     EphyNode *bookmark)
+{
+	GValue value = { 0, };
+	char *to_uri;
+
+	if (response == GTK_RESPONSE_ACCEPT)
+	{
+		to_uri = (char *) g_object_steal_data (G_OBJECT (dialog),
+						       UPDATE_URI_DATA_KEY);
+
+		g_value_init (&value, G_TYPE_STRING);
+		g_value_take_string (&value, to_uri);
+		ephy_node_set_property (bookmark, EPHY_NODE_BMK_PROP_LOCATION,
+					&value);
+		g_value_unset (&value);
+	}
+
+	gtk_widget_destroy (dialog);
+}
+
+static void
+update_bookmark_destroy_cb (EphyNode *zombie,
+			    GtkWidget *dialog)
+{
+	gtk_widget_destroy (dialog);
+}
+
+static void
+redirect_cb (EphyHistory *history,
+	      const char *from_uri,
+	      const char *to_uri,
+	      EphyBookmarks *eb)
+{
+	EphyNode *bookmark;
+	GtkWidget *dialog;
+	const char *title;
+
+	bookmark = ephy_bookmarks_find_bookmark (eb, from_uri);
+
+	/* FIXME check if there's another update-bookmark dialog up
+	 * for from_uri' -> from_uri and update it accordingly
+	 */
+	if (bookmark == NULL) return;
+
+	title = ephy_node_get_property_string (bookmark, EPHY_NODE_BMK_PROP_TITLE);
+
+	dialog = gtk_message_dialog_new
+			(NULL, GTK_DIALOG_DESTROY_WITH_PARENT,
+				GTK_MESSAGE_QUESTION,
+				GTK_BUTTONS_NONE,
+				/* translators: the %s is the title of the bookmark */
+				_("Update bookmark \"%s\"?"),
+				title);
+	gtk_message_dialog_format_secondary_markup
+		(GTK_MESSAGE_DIALOG (dialog),
+		/* translators: the %s is a URL */
+		_("The bookmarked page has moved to <tt>%s</tt>."),
+		to_uri);
+
+	gtk_dialog_add_button (GTK_DIALOG (dialog),
+				_("_Don't update bookmark"), GTK_RESPONSE_REJECT);
+	gtk_dialog_add_button (GTK_DIALOG (dialog),
+				_("_Update bookmark"), GTK_RESPONSE_ACCEPT);
+	gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_REJECT);
+
+	gtk_window_set_title (GTK_WINDOW (dialog), _("Update bookmark?"));
+	gtk_window_set_icon_name (GTK_WINDOW (dialog), "web-browser");
+
+	g_object_set_data_full (G_OBJECT (dialog), UPDATE_URI_DATA_KEY,
+				g_strdup (to_uri), (GDestroyNotify) g_free);
+	g_signal_connect (dialog, "response",
+			  G_CALLBACK (update_bookmark_response_cb), bookmark);
+	ephy_node_signal_connect_object (bookmark,
+					 EPHY_NODE_DESTROY,
+					 (EphyNodeCallback) update_bookmark_destroy_cb,
+					 G_OBJECT (dialog));
+
+	gtk_window_present (GTK_WINDOW (dialog));
+}
+
 static void
 ephy_setup_history_notifiers (EphyBookmarks *eb)
 {
@@ -494,6 +578,8 @@ ephy_setup_history_notifiers (EphyBookmarks *eb)
 			  G_CALLBACK (history_site_visited_cb), eb);
 	g_signal_connect (history, "cleared",
 			  G_CALLBACK (history_cleared_cb), eb);
+	g_signal_connect (history, "redirect",
+			  G_CALLBACK (redirect_cb), eb);
 }
 
 static void
