@@ -15,12 +15,10 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-topics-selector.c,v 1.27 2004/10/27 19:54:57 chpe Exp $
+ *  $Id: ephy-topics-selector.c,v 1.28 2004/11/02 20:57:34 chpe Exp $
  */
 
-#ifdef HAVE_CONFIG_H
 #include "config.h"
-#endif
 
 #include "ephy-topics-selector.h"
 #include "ephy-debug.h"
