@@ -15,12 +15,10 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-favicon-action.c,v 1.30 2004/10/27 19:54:57 chpe Exp $
+ *  $Id: ephy-favicon-action.c,v 1.31 2004/11/02 20:57:21 chpe Exp $
  */
 
-#ifdef HAVE_CONFIG_H
 #include "config.h"
-#endif
 
 #include "ephy-favicon-action.h"
 #include "ephy-window.h"
