@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-main.c,v 1.29 2004/11/11 12:52:20 chpe Exp $
+ *  $Id: ephy-main.c,v 1.33 2004/12/17 21:49:55 chpe Exp $
  */
 
 #include "config.h"
@@ -29,13 +29,14 @@
 
 #include <libgnomeui/gnome-ui-init.h>
 #include <libgnomeui/gnome-app-helper.h>
+#include <gtk/gtkaboutdialog.h>
 #include <gtk/gtkmain.h>
 #include <gtk/gtkmessagedialog.h>
 #include <libgnome/gnome-program.h>
 #include <bonobo/bonobo-main.h>
 #include <glib/gi18n.h>
-#include <glade/glade-init.h>
 #include <libgnomevfs/gnome-vfs-init.h>
+#include <libgnomevfs/gnome-vfs-utils.h>
 #include <libxml/xmlversion.h>
 
 static gboolean open_in_existing = FALSE;
@@ -70,6 +71,27 @@ static struct poptOption popt_options[] =
 	{ NULL, 0, 0, NULL, 0, NULL, NULL }
 };
 
+static void
+handle_url (GtkAboutDialog *about,
+	    const char *link,
+	    gpointer data)
+{
+	ephy_shell_new_tab (ephy_shell, NULL, NULL, link,
+			    EPHY_NEW_TAB_OPEN_PAGE);
+}
+
+static void
+handle_email (GtkAboutDialog *about,
+	      const char *link,
+	      gpointer data)
+{
+	char *address;
+
+	address = g_strdup_printf ("mailto:%s\n", link);
+	gnome_vfs_url_show (address);
+	g_free (address);
+}
+
 static void
 shell_weak_notify (gpointer data,
                    GObject *where_the_object_was)
@@ -160,7 +182,6 @@ main (int argc, char *argv[])
 	}
 
 	gnome_vfs_init ();
-	glade_gnome_init ();
 	ephy_debug_init ();
 	ephy_file_helpers_init ();
 	ephy_stock_icons_init ();
@@ -168,6 +189,10 @@ main (int argc, char *argv[])
 	eel_gconf_monitor_add ("/apps/epiphany/lockdown");
 	eel_gconf_monitor_add ("/desktop/gnome/lockdown");
 
+	/* Extensions may want these, so don't initialize in window-cmds */
+	gtk_about_dialog_set_url_hook (handle_url, NULL, NULL);
+	gtk_about_dialog_set_email_hook (handle_email, NULL, NULL);
+
 	bonobo_activate ();
 
 	ephy_shell = ephy_shell_new ();
@@ -198,6 +223,7 @@ main (int argc, char *argv[])
 	ephy_state_save ();
 	ephy_file_helpers_shutdown ();
 	gnome_vfs_shutdown ();
+	xmlCleanupParser ();
 	poptFreeContext (context);
 
 	return 0;
