@@ -17,12 +17,10 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id$
+ *  $Id: ephy-session.c,v 1.33 2004/12/13 18:58:58 chpe Exp $
  */
 
-#ifdef HAVE_CONFIG_H
 #include "config.h"
-#endif
 
 #include "ephy-session.h"
 
@@ -31,7 +29,6 @@
 #include "ephy-shell.h"
 #include "ephy-history-window.h"
 #include "ephy-bookmarks-editor.h"
-#include "ephy-string.h"
 #include "ephy-file-helpers.h"
 #include "eel-gconf-extensions.h"
 #include "ephy-prefs.h"
@@ -59,7 +56,7 @@ struct EphySessionPrivate
 	GList *windows;
 	GList *tool_windows;
 	GtkWidget *resume_dialog;
-	gboolean resuming;
+	gboolean dont_save;
 };
 
 #define BOOKMARKS_EDITOR_ID	"BookmarksEditor"
@@ -370,11 +367,12 @@ offer_to_resume (EphySession *session)
 		 GTK_DIALOG_MODAL,
 		 GTK_MESSAGE_WARNING,
 		 GTK_BUTTONS_NONE,
-		 _("Epiphany appears to have crashed or been killed the last time it was run."));
+		 _("Recover previous browser windows and tabs?"));
 
 	gtk_message_dialog_format_secondary_text
 		(GTK_MESSAGE_DIALOG (dialog),
-		 _("You can recover the opened tabs and windows."));
+		 _("Epiphany appears to have exited unexpectedly the last time "
+		   "it was run. You can recover the opened windows and tabs."));
 	
 	gtk_dialog_add_button (GTK_DIALOG (dialog),
 			       _("_Don't Recover"), GTK_RESPONSE_CANCEL);
@@ -414,7 +412,7 @@ ephy_session_autoresume (EphySession *session)
 
 	LOG ("ephy_session_autoresume")
 
-	if (session->priv->windows != NULL) return FALSE;
+	if (session->priv->windows != NULL || session->priv->tool_windows != NULL) return FALSE;
 
 	if (session->priv->resume_dialog)
 	{
@@ -427,9 +425,9 @@ ephy_session_autoresume (EphySession *session)
 	if (g_file_test (saved_session, G_FILE_TEST_EXISTS)
 	    && offer_to_resume (session))
 	{
-		session->priv->resuming = TRUE;
+		session->priv->dont_save = TRUE;
 		retval = ephy_session_load (session, saved_session);
-		session->priv->resuming = FALSE;
+		session->priv->dont_save = FALSE;
 		ephy_session_save (session, SESSION_CRASHED);
 	}
 
@@ -445,6 +443,12 @@ ephy_session_close (EphySession *session)
 
 	LOG ("ephy_session_close")
 
+	/* we have to ref the shell or else we may get finalised between
+	 * destroying the windows and destroying the tool windows
+	 */
+	g_object_ref (ephy_shell);
+	session->priv->dont_save = TRUE;
+
 	windows	= ephy_session_get_windows (session);
 	g_list_foreach (windows, (GFunc) gtk_widget_destroy, NULL);
 	g_list_free (windows);
@@ -452,6 +456,9 @@ ephy_session_close (EphySession *session)
 	windows = g_list_copy (session->priv->tool_windows);
 	g_list_foreach (windows, (GFunc) gtk_widget_destroy, NULL);
 	g_list_free (windows);	
+
+	session->priv->dont_save = FALSE;
+	g_object_unref (ephy_shell);
 }
 
 static int
@@ -575,7 +582,7 @@ ephy_session_save (EphySession *session,
 	char *save_to, *tmp_file;
 	int ret;
 
-	if (session->priv->resuming)
+	if (session->priv->dont_save)
 	{
 		return TRUE;
 	}
