@@ -17,16 +17,13 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-statusbar.c,v 1.10 2004/10/27 20:10:34 chpe Exp $
+ *  $Id: ephy-statusbar.c,v 1.14 2004/12/13 18:58:58 chpe Exp $
  */
 
-#ifdef HAVE_CONFIG_H
 #include "config.h"
-#endif
 
 #include "ephy-statusbar.h"
 #include "ephy-stock-icons.h"
-#include "ephy-string.h"
 
 #include <string.h>
 #include <gtk/gtkprogressbar.h>
@@ -197,14 +194,12 @@ ephy_statusbar_init (EphyStatusbar *t)
 	gtk_box_reorder_child (GTK_BOX (t), t->priv->icon_container, 0);
 	gtk_widget_show (t->priv->icon_container);
 
-	/* FIXME: enable this when gtk+ bug 73359 is fixed */
-	gtk_statusbar_set_has_resize_grip (GTK_STATUSBAR (t), FALSE);
+	gtk_statusbar_set_has_resize_grip (GTK_STATUSBAR (t), TRUE);
 
 	create_statusbar_progress (t);
 	create_statusbar_security_icon (t);
 	create_statusbar_popups_manager_icon (t);
 
-	/* FIXME: is this the right way ? */
 	sync_shadow_type (t, NULL, NULL);
 	g_signal_connect (t, "style-set", G_CALLBACK (sync_shadow_type), NULL);
 }
