@@ -16,12 +16,10 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-toolbars-model.c,v 1.29 2004/06/11 16:14:59 chpe Exp $
+ *  $Id: ephy-toolbars-model.c,v 1.33 2004/11/02 20:57:21 chpe Exp $
  */
 
-#ifdef HAVE_CONFIG_H
 #include "config.h"
-#endif
 
 #include "ephy-toolbars-model.h"
 #include "ephy-file-helpers.h"
@@ -50,7 +48,7 @@ ephy_toolbars_model_get_type (void)
 {
 	static GType type = 0;
 
-	if (type == 0)
+	if (G_UNLIKELY (type == 0))
 	{
 		static const GTypeInfo our_info = {
 		sizeof (EphyToolbarsModelClass),
@@ -121,7 +119,9 @@ update_flags_and_save_changes (EphyToolbarsModel *model)
 		g_return_if_fail (t_name != NULL);
 
 		flags = egg_toolbars_model_get_flags (eggmodel, i);
-		egg_toolbars_model_set_flags (eggmodel, flags | flag, i);
+		flags &= ~EGG_TB_MODEL_NOT_REMOVABLE;
+		flags |= flag;
+		egg_toolbars_model_set_flags (eggmodel, i, flags);
 	}
 
 	save_changes (model);
