@@ -17,12 +17,10 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-window.c,v 1.228 2004/11/01 14:48:55 chpe Exp $
+ *  $Id: ephy-window.c,v 1.243 2004/12/19 13:26:37 chpe Exp $
  */
 
-#ifdef HAVE_CONFIG_H
 #include "config.h"
-#endif
 
 #include "ephy-window.h"
 #include "ephy-command-manager.h"
@@ -52,6 +50,7 @@
 #include "ephy-stock-icons.h"
 #include "ephy-extension.h"
 #include "ephy-favicon-cache.h"
+#include "ephy-gui.h"
 
 #include <string.h>
 #include <glib/gi18n.h>
@@ -83,10 +82,14 @@ static void ephy_window_view_bookmarksbar_cb    (GtkAction *action,
 			                         EphyWindow *window);
 static void ephy_window_view_popup_windows_cb	(GtkAction *action,
 						 EphyWindow *window);
+static void sync_tab_zoom			(EphyTab *tab,
+						 GParamSpec *pspec,
+						 EphyWindow *window);
 
 static GtkActionEntry ephy_menu_entries [] = {
 
 	/* Toplevel */
+
 	{ "File", NULL, N_("_File") },
 	{ "Edit", NULL, N_("_Edit") },
 	{ "View", NULL, N_("_View") },
@@ -98,6 +101,7 @@ static GtkActionEntry ephy_menu_entries [] = {
 	{ "PopupAction", NULL, "" },
 
 	/* File menu */
+
 	{ "FileNewWindow", GTK_STOCK_NEW, N_("_New Window"), "<control>N",
 	  N_("Open a new window"),
 	  G_CALLBACK (window_cmd_file_new_window) },
@@ -122,7 +126,7 @@ static GtkActionEntry ephy_menu_entries [] = {
 	{ "FilePrint", GTK_STOCK_PRINT, N_("_Print..."), "<control>P",
 	  N_("Print the current page"),
 	  G_CALLBACK (window_cmd_file_print) },
-	{ "FileSendTo", STOCK_SEND_MAIL, N_("S_end To..."), NULL,
+	{ "FileSendTo", STOCK_SEND_MAIL, N_("S_end To..."), "<control>M",
 	  N_("Send a link of the current page"),
 	  G_CALLBACK (window_cmd_file_send_to) },
 	{ "FileCloseWindow", GTK_STOCK_CLOSE, N_("_Close"), "<control>W",
@@ -130,6 +134,7 @@ static GtkActionEntry ephy_menu_entries [] = {
 	  G_CALLBACK (window_cmd_file_close_window) },
 
 	/* Edit menu */
+
 	{ "EditUndo", GTK_STOCK_UNDO, N_("_Undo"), "<control>Z",
 	  N_("Undo the last action"),
 	  G_CALLBACK (window_cmd_edit_undo) },
@@ -168,6 +173,7 @@ static GtkActionEntry ephy_menu_entries [] = {
 	  G_CALLBACK (window_cmd_edit_prefs) },
 
 	/* View menu */
+
 	{ "ViewStop", GTK_STOCK_STOP, N_("_Stop"), "Escape",
 	  N_("Stop current data transfer"),
 	  G_CALLBACK (window_cmd_view_stop) },
@@ -191,6 +197,7 @@ static GtkActionEntry ephy_menu_entries [] = {
 	  G_CALLBACK (window_cmd_view_page_source) },
 
 	/* Bookmarks menu */
+
 	{ "FileBookmarkPage", STOCK_ADD_BOOKMARK, N_("_Add Bookmark..."), "<control>D",
 	  N_("Add a bookmark for the current page"),
 	  G_CALLBACK (window_cmd_file_bookmark_page) },
@@ -199,6 +206,7 @@ static GtkActionEntry ephy_menu_entries [] = {
 	  G_CALLBACK (window_cmd_go_bookmarks) },
 
 	/* Go menu */
+
 	{ "GoBack", GTK_STOCK_GO_BACK, N_("_Back"), "<alt>Left",
 	  N_("Go to the previous visited page"),
 	  G_CALLBACK (window_cmd_go_back) },
@@ -219,6 +227,7 @@ static GtkActionEntry ephy_menu_entries [] = {
 	  G_CALLBACK (window_cmd_go_history) },
 
 	/* Tabs menu */
+
 	{ "TabsPrevious", NULL, N_("_Previous Tab"), "<control>Page_Up",
 	  N_("Activate previous tab"),
 	  G_CALLBACK (window_cmd_tabs_previous) },
@@ -236,6 +245,7 @@ static GtkActionEntry ephy_menu_entries [] = {
 	  G_CALLBACK (window_cmd_tabs_detach) },
 
 	/* Help menu */
+
 	{"HelpContents", GTK_STOCK_HELP, N_("_Contents"), "F1",
 	 N_("Display web browser help"),
 	 G_CALLBACK (window_cmd_help_contents) },
@@ -248,11 +258,13 @@ static guint ephy_menu_n_entries = G_N_ELEMENTS (ephy_menu_entries);
 static GtkToggleActionEntry ephy_menu_toggle_entries [] =
 {
 	/* File Menu */
+
 	{ "FileWorkOffline", NULL, N_("_Work Offline"), NULL,
 	  N_("Toggle network status"),
 	  G_CALLBACK (window_cmd_file_work_offline), FALSE },
 
 	/* View Menu */
+
 	{ "ViewToolbar", NULL, N_("_Toolbar"), "<shift><control>T",
 	  N_("Show or hide toolbar"),
 	  G_CALLBACK (ephy_window_view_toolbar_cb), TRUE },
@@ -276,6 +288,7 @@ static guint ephy_menu_n_toggle_entries = G_N_ELEMENTS (ephy_menu_toggle_entries
 
 static GtkActionEntry ephy_popups_entries [] = {
 	/* Document */
+
 	{ "SaveBackgroundAs", NULL, N_("_Save Background As..."), NULL,
 	  NULL, G_CALLBACK (popup_cmd_save_background_as) },
 	{ "ContextBookmarkPage", STOCK_ADD_BOOKMARK, N_("Add Boo_kmark..."), "<control>D",
@@ -283,11 +296,13 @@ static GtkActionEntry ephy_popups_entries [] = {
 	  G_CALLBACK (window_cmd_file_bookmark_page) },
 
 	/* Framed document */
-	{ "OpenFrame", NULL, N_("_Open Frame"), NULL,
-	  N_("Open frame in this window"),
+
+	{ "OpenFrame", NULL, N_("Show Only This _Frame"), NULL,
+	  N_("Show only this frame in this window"),
 	  G_CALLBACK (popup_cmd_open_frame) },
 
 	/* Links */
+
 	{ "OpenLink", GTK_STOCK_OPEN, N_("_Open Link"), NULL,
 	  N_("Open link in this window"),
 	  G_CALLBACK (popup_cmd_open_link) },
@@ -308,12 +323,15 @@ static GtkActionEntry ephy_popups_entries [] = {
 	  NULL, G_CALLBACK (popup_cmd_copy_link_address) },
 
 	/* Email links */
+
+	/* This is on the context menu on a mailto: link and opens the mail program */
 	{ "SendEmail", GTK_STOCK_OPEN, N_("_Send Email..."),
 	  NULL, NULL, G_CALLBACK (popup_cmd_open_link) },
 	{ "CopyEmailAddress", NULL, N_("_Copy Email Address"), NULL,
 	  NULL, G_CALLBACK (popup_cmd_copy_link_address) },
 
 	/* Images */
+
 	{ "OpenImage", GTK_STOCK_OPEN, N_("Open _Image"), NULL,
 	  NULL, G_CALLBACK (popup_cmd_open_image) },
 	{ "SaveImageAs", GTK_STOCK_SAVE_AS, N_("_Save Image As..."), NULL,
@@ -471,6 +489,7 @@ static void
 ephy_window_destroy (GtkObject *gtkobject)
 {
 	EphyWindow *window = EPHY_WINDOW (gtkobject);
+	GSList *popups;
 
 	LOG ("EphyWindow destroy %p", window)
 
@@ -487,6 +506,10 @@ ephy_window_destroy (GtkObject *gtkobject)
 
 	destroy_exit_fullscreen_popup (window);
 
+	popups = gtk_ui_manager_get_toplevels (window->priv->manager, GTK_UI_MANAGER_POPUP);
+	g_slist_foreach (popups, (GFunc) gtk_menu_shell_deactivate, NULL);
+	g_slist_free (popups);
+
         GTK_OBJECT_CLASS (parent_class)->destroy (gtkobject);
 }
 
@@ -670,7 +693,6 @@ static gboolean
 confirm_close_with_modified_forms (EphyWindow *window)
 {
 	GtkWidget *dialog;
-	GtkWindowGroup *group;
 	int response;
 
 	dialog = gtk_message_dialog_new
@@ -693,15 +715,7 @@ confirm_close_with_modified_forms (EphyWindow *window)
 	/* FIXME set title */
 	gtk_window_set_icon_name (GTK_WINDOW (dialog), "web-browser");
 
-	group = GTK_WINDOW (window)->group;
-	if (group == NULL)
-	{
-		group = gtk_window_group_new ();
-		gtk_window_group_add_window (group, GTK_WINDOW (window));
-		g_object_unref (group);
-	}
-
-	gtk_window_group_add_window (group, GTK_WINDOW (dialog));
+	gtk_window_group_add_window (GTK_WINDOW (window)->group, GTK_WINDOW (dialog));
 
 	response = gtk_dialog_run (GTK_DIALOG (dialog));
 
@@ -1029,14 +1043,34 @@ update_chromes_actions (EphyWindow *window)
 		 			   window);
 }
 
+static void
+update_print_actions (EphyWindow *window,
+		      gboolean enable)
+{
+	GtkActionGroup *action_group = window->priv->action_group;
+	GtkAction *action;
+	gboolean printing, print_setup;
+
+	printing = !eel_gconf_get_boolean (CONF_LOCKDOWN_DISABLE_PRINTING);
+	print_setup = !eel_gconf_get_boolean (CONF_LOCKDOWN_DISABLE_PRINT_SETUP) &&
+		!eel_gconf_get_boolean (CONF_LOCKDOWN_DISABLE_COMMAND_LINE);
+
+	action = gtk_action_group_get_action (action_group, "FilePrintSetup");
+	g_object_set (action, "sensitive", printing && print_setup, NULL);
+	action = gtk_action_group_get_action (action_group, "FilePrintPreview");
+	g_object_set (action, "sensitive", enable && printing && print_setup, NULL);
+	action = gtk_action_group_get_action (action_group, "FilePrint");
+	g_object_set (action, "sensitive", enable && printing, NULL);
+
+}
+
 static void
 update_actions_sensitivity (EphyWindow *window)
 {
 	GtkActionGroup *action_group = window->priv->action_group;
 	GtkActionGroup *popups_action_group = window->priv->popups_action_group;
 	GtkAction *action;
-	gboolean bookmarks_editable, save_to_disk;
-	gboolean printing, print_setup, fullscreen;
+	gboolean bookmarks_editable, save_to_disk, fullscreen;
 
 	action = gtk_action_group_get_action (action_group, "ViewToolbar");
 	g_object_set (action, "sensitive", eel_gconf_key_is_writable (CONF_WINDOWS_SHOW_TOOLBARS), NULL);
@@ -1074,17 +1108,6 @@ update_actions_sensitivity (EphyWindow *window)
 	g_object_set (action, "sensitive", save_to_disk, NULL);
 	action = gtk_action_group_get_action (popups_action_group, "SaveImageAs");
 	g_object_set (action, "sensitive", save_to_disk, NULL);
-
-	printing = !eel_gconf_get_boolean (CONF_LOCKDOWN_DISABLE_PRINTING);
-	print_setup = !eel_gconf_get_boolean (CONF_LOCKDOWN_DISABLE_PRINT_SETUP) &&
-		!eel_gconf_get_boolean (CONF_LOCKDOWN_DISABLE_COMMAND_LINE);
-	action = gtk_action_group_get_action (action_group, "FilePrintSetup");
-	g_object_set (action, "sensitive", printing && print_setup, NULL);
-	action = gtk_action_group_get_action (action_group, "FilePrintPreview");
-	g_object_set (action, "sensitive", printing && print_setup, NULL);
-	action = gtk_action_group_get_action (action_group, "FilePrint");
-	g_object_set (action, "sensitive", printing, NULL);
-
 	action = gtk_action_group_get_action (popups_action_group, "SetImageAsBackground");
 	g_object_set (action, "sensitive", eel_gconf_key_is_writable (CONF_DESKTOP_BG_PICTURE), NULL);
 
@@ -1098,6 +1121,8 @@ update_actions_sensitivity (EphyWindow *window)
 	g_object_set (action, "sensitive", !fullscreen, NULL);
 	action = gtk_action_group_get_action (action_group, "TabsDetach");
 	g_object_set (action, "sensitive", !fullscreen, NULL);
+
+	update_print_actions (window, TRUE);
 }
 
 static void
@@ -1196,6 +1221,36 @@ sync_tab_address (EphyTab *tab, GParamSpec *pspec, EphyWindow *window)
 	toolbar_set_location (window->priv->toolbar, address);
 }
 
+static void
+sync_tab_document_type (EphyTab *tab,
+			GParamSpec *pspec,
+			EphyWindow *window)
+{
+	GtkActionGroup *action_group;
+	GtkAction *action;
+	EmbedDocumentType type;
+	gboolean can_find, enable;
+
+	/* update zoom actions */
+	sync_tab_zoom (tab, NULL, window);
+	
+	type = ephy_tab_get_document_type (tab);
+	can_find = (type != EMBED_DOCUMENT_IMAGE);
+	enable = (type == EMBED_DOCUMENT_HTML);
+
+	action_group = window->priv->action_group;
+	action = gtk_action_group_get_action (action_group, "ViewEncoding");
+	g_object_set (action, "sensitive", enable, NULL);
+	action = gtk_action_group_get_action (action_group, "ViewPageSource");
+	g_object_set (action, "sensitive", enable, NULL);
+	action = gtk_action_group_get_action (action_group, "EditFind");
+	g_object_set (action, "sensitive", can_find, NULL);
+	action = gtk_action_group_get_action (action_group, "EditFindNext");
+	g_object_set (action, "sensitive", can_find, NULL);
+	action = gtk_action_group_get_action (action_group, "EditFindPrev");
+	g_object_set (action, "sensitive", can_find, NULL);
+}
+
 static void
 sync_tab_icon (EphyTab *tab, GParamSpec *pspec, EphyWindow *window)
 {
@@ -1433,6 +1488,9 @@ sync_tab_load_status (EphyTab *tab, GParamSpec *pspec, EphyWindow *window)
 	status = ephy_tab_get_load_status (tab);
 	g_object_set (action, "sensitive", status, NULL);
 
+	/* disable print while loading, see bug #116344 */
+	update_print_actions (window, !status);
+
 	if (status)
 	{
 		toolbar_spinner_start (window->priv->toolbar);
@@ -1496,12 +1554,15 @@ sync_tab_zoom (EphyTab *tab, GParamSpec *pspec, EphyWindow *window)
 {
 	GtkActionGroup *action_group;
 	GtkAction *action;
-	gboolean can_zoom_in = TRUE, can_zoom_out = TRUE, can_zoom_normal = FALSE;
+	EmbedDocumentType type;
+	gboolean can_zoom_in = TRUE, can_zoom_out = TRUE, can_zoom_normal = FALSE, can_zoom;
 	float zoom;
 
 	if (window->priv->closing) return;
 
 	zoom = ephy_tab_get_zoom (tab);
+	type = ephy_tab_get_document_type (tab);
+	can_zoom = (type != EMBED_DOCUMENT_IMAGE);
 
 	if (zoom >= ZOOM_MAXIMAL)
 	{
@@ -1516,15 +1577,15 @@ sync_tab_zoom (EphyTab *tab, GParamSpec *pspec, EphyWindow *window)
 		can_zoom_normal = TRUE;
 	}
 
-	toolbar_update_zoom (window->priv->toolbar, zoom);
+	toolbar_update_zoom (window->priv->toolbar, can_zoom, zoom);
 
 	action_group = window->priv->action_group;
 	action = gtk_action_group_get_action (action_group, "ViewZoomIn");
-	g_object_set (action, "sensitive", can_zoom_in, NULL);
+	g_object_set (action, "sensitive", can_zoom_in && can_zoom, NULL);
 	action = gtk_action_group_get_action (action_group, "ViewZoomOut");
-	g_object_set (action, "sensitive", can_zoom_out, NULL);
+	g_object_set (action, "sensitive", can_zoom_out && can_zoom, NULL);
 	action = gtk_action_group_get_action (action_group, "ViewZoomNormal");
-	g_object_set (action, "sensitive", can_zoom_normal, NULL);
+	g_object_set (action, "sensitive", can_zoom_normal && can_zoom, NULL);
 }
 
 static void
@@ -1547,10 +1608,17 @@ static void
 popup_menu_at_coords (GtkMenu *menu, gint *x, gint *y, gboolean *push_in,
 		      gpointer user_data)
 {
-	EphyEmbedEvent *event = (EphyEmbedEvent *) user_data;
+	GtkWidget *window = GTK_WIDGET (user_data);
+	EphyEmbedEvent *event;
+
+	event = g_object_get_data (G_OBJECT (window), "context_event");
+	g_return_if_fail (event != NULL);
 
 	ephy_embed_event_get_coords (event, x, y);
 
+	/* FIXME: better position the popup within the window bounds? */
+	ephy_gui_sanitise_popup_position (menu, window, x, y);
+
 	*push_in = TRUE;
 }
 
@@ -1763,8 +1831,9 @@ show_embed_popup (EphyWindow *window, EphyTab *tab, EphyEmbedEvent *event)
 	if (type == EPHY_EMBED_EVENT_KEY)
 	{
 		gtk_menu_popup (GTK_MENU (widget), NULL, NULL,
-				popup_menu_at_coords, event, 2,
+				popup_menu_at_coords, window, 0,
 				gtk_get_current_event_time ());
+		gtk_menu_shell_select_first (GTK_MENU_SHELL (widget), FALSE);
 	}
 	else
 	{
@@ -1813,6 +1882,9 @@ ephy_window_set_active_tab (EphyWindow *window, EphyTab *new_tab)
 		g_signal_handlers_disconnect_by_func (G_OBJECT (old_tab),
 						      G_CALLBACK (sync_tab_address),
 						      window);
+		g_signal_handlers_disconnect_by_func (G_OBJECT (old_tab),
+						      G_CALLBACK (sync_tab_document_type),
+						      window);
 		g_signal_handlers_disconnect_by_func (G_OBJECT (old_tab),
 						      G_CALLBACK (sync_tab_icon),
 						      window);
@@ -1858,6 +1930,7 @@ ephy_window_set_active_tab (EphyWindow *window, EphyTab *new_tab)
 	if (new_tab)
 	{
 		sync_tab_address	(new_tab, NULL, window);
+		sync_tab_document_type	(new_tab, NULL, window);
 		sync_tab_icon		(new_tab, NULL, window);
 		sync_tab_load_progress	(new_tab, NULL, window);
 		sync_tab_load_status	(new_tab, NULL, window);
@@ -1873,6 +1946,10 @@ ephy_window_set_active_tab (EphyWindow *window, EphyTab *new_tab)
 					 "notify::address",
 					 G_CALLBACK (sync_tab_address),
 					 window, 0);
+		g_signal_connect_object (G_OBJECT (new_tab),
+					 "notify::document-type",
+					 G_CALLBACK (sync_tab_document_type),
+					 window, 0);
 		g_signal_connect_object (G_OBJECT (new_tab),
 					 "notify::icon",
 					 G_CALLBACK (sync_tab_icon),
@@ -1967,7 +2044,12 @@ modal_alert_cb (EphyEmbed *embed,
 	tab = ephy_tab_for_embed (embed);
 	g_return_val_if_fail (tab != NULL, FALSE);
 
+	/* switch the window to the tab, and bring the window to the foreground
+	 * (since the alert is modal, the user won't be able to do anything
+	 * with his current window anyway :|)
+	 */
 	ephy_window_jump_to_tab (window, tab);
+	gtk_window_present (GTK_WINDOW (window));
 
 	/* make sure the location entry shows the real URL of the tab's page */
 	address = ephy_embed_get_location (embed, TRUE);
@@ -1983,6 +2065,7 @@ tab_added_cb (EphyNotebook *notebook,
 	      EphyTab *tab,
 	      EphyWindow *window)
 {
+	EphyExtension *manager;
 	EphyEmbed *embed;
 
         g_return_if_fail (EPHY_IS_TAB (tab));
@@ -1999,6 +2082,10 @@ tab_added_cb (EphyNotebook *notebook,
 
 	g_signal_connect_after (embed, "ge-modal-alert",
 				G_CALLBACK (modal_alert_cb), window);
+
+	/* Let the extensions attach themselves to the tab */
+	manager = EPHY_EXTENSION (ephy_shell_get_extensions_manager (ephy_shell));
+	ephy_extension_attach_tab (manager, window, tab);
 }
 
 static void
@@ -2006,10 +2093,15 @@ tab_removed_cb (EphyNotebook *notebook,
 		EphyTab *tab,
 		EphyWindow *window)
 {
+	EphyExtension *manager;
 	EphyEmbed *embed;
 
         g_return_if_fail (EPHY_IS_TAB (tab));
 
+	/* Let the extensions remove themselves from the tab */
+	manager = EPHY_EXTENSION (ephy_shell_get_extensions_manager (ephy_shell));
+	ephy_extension_detach_tab (manager, window, tab);
+
 	g_signal_handlers_disconnect_by_func (G_OBJECT (tab),
 					      G_CALLBACK (sync_tab_visibility),
 					      window);	
@@ -2346,11 +2438,13 @@ ephy_window_init (EphyWindow *window)
 
 	LOG ("EphyWindow initialising %p", window)
 
+	g_object_ref (ephy_shell);
+
 	window->priv = EPHY_WINDOW_GET_PRIVATE (window);
 
 	window->priv->chrome = EPHY_EMBED_CHROME_ALL;
 
-	g_object_ref (ephy_shell);
+	ephy_gui_ensure_window_group (GTK_WINDOW (window));
 
 	/* Setup the UI manager and connect verbs */
 	setup_ui_manager (window);
@@ -2816,13 +2910,7 @@ ephy_window_activate_location (EphyWindow *window)
 	toolbar_activate_location (window->priv->toolbar);
 }
 
-/**
- * ephy_window_show:
- * @widget: an #EphyWindow
- *
- * Shows @widget if it is hidden.
- **/
-void
+static void
 ephy_window_show (GtkWidget *widget)
 {
 	EphyWindow *window = EPHY_WINDOW(widget);
