@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: window-commands.c,v 1.144 2004/11/25 19:01:26 marco Exp $
+ *  $Id: window-commands.c,v 1.146 2004/12/18 22:16:40 chpe Exp $
  */
 
 #include "config.h"
@@ -52,13 +52,14 @@
 #include <libgnomevfs/gnome-vfs-utils.h>
 #include <libgnomeui/gnome-stock-icons.h>
 #include <libgnomevfs/gnome-vfs-mime-handlers.h>
+#include <gtk/gtkaboutdialog.h>
 #include <gtk/gtkeditable.h>
 #include <gtk/gtkmain.h>
 #include <gtk/gtkicontheme.h>
 #include <gtk/gtktoggleaction.h>
-#include <gtk/gtkaboutdialog.h>
 #include <glib/gi18n.h>
 
+#define TOOLBAR_EDITOR_KEY	"EphyToolbarEditor"
 enum
 {
 	RESPONSE_ADD_TOOLBAR
@@ -794,6 +795,8 @@ toolbar_editor_destroy_cb (GtkWidget *tbe,
 		(ephy_window_get_toolbar (window)), FALSE);
 	egg_editable_toolbar_set_edit_mode (EGG_EDITABLE_TOOLBAR
 		(ephy_window_get_bookmarksbar (window)), FALSE);
+
+	g_object_set_data (G_OBJECT (window), TOOLBAR_EDITOR_KEY, NULL);
 }
 
 static void
@@ -819,14 +822,19 @@ void
 window_cmd_edit_toolbar (GtkAction *action,
 			 EphyWindow *window)
 {
-	GtkWidget *editor;
+	GtkWidget *editor, *dialog, *toolbar;
 	EggToolbarsModel *model;
-	GtkWidget *t;
-	GtkWidget *dialog;
+
+	dialog = GTK_WIDGET (g_object_get_data (G_OBJECT (window), TOOLBAR_EDITOR_KEY));
+	if (dialog != NULL)
+	{
+		gtk_window_present (GTK_WINDOW (dialog));
+		return;
+	}
 
 	model = EGG_TOOLBARS_MODEL
 		(ephy_shell_get_toolbars_model (ephy_shell, FALSE));
-	t = ephy_window_get_toolbar (window);
+	toolbar = ephy_window_get_toolbar (window);
 
 	dialog = gtk_dialog_new ();
 	gtk_dialog_set_has_separator (GTK_DIALOG (dialog), FALSE);
@@ -863,9 +871,11 @@ window_cmd_edit_toolbar (GtkAction *action,
 			       EPHY_STATE_WINDOW_SAVE_SIZE);
 	gtk_widget_show (dialog);
 
-	egg_editable_toolbar_set_edit_mode (EGG_EDITABLE_TOOLBAR (t), TRUE);
+	egg_editable_toolbar_set_edit_mode (EGG_EDITABLE_TOOLBAR (toolbar), TRUE);
 	egg_editable_toolbar_set_edit_mode
 		(EGG_EDITABLE_TOOLBAR (ephy_window_get_bookmarksbar (window)), TRUE);
+
+	g_object_set_data (G_OBJECT (window), TOOLBAR_EDITOR_KEY, dialog);
 }
 
 void
@@ -879,9 +889,6 @@ void
 window_cmd_help_about (GtkAction *action,
 		       GtkWidget *window)
 {
-	static GtkWidget *about = NULL;
-	GtkWidget** ptr;
-
 	static char *authors[] = {
 		"Marco Pesenti Gritti <marco@gnome.org>",
 		"Xan Lopez <xan@gnome.org>",
@@ -890,42 +897,23 @@ window_cmd_help_about (GtkAction *action,
 		NULL
 	};
 
-	char *documenters[] = {
+	static char *documenters[] = {
 		"Patanjali Somayaji <patanjali@codito.com>",
 		"David Bordoley <bordoley@msu.edu>",
 		"Piers Cornwell <piers@gnome.org>", 
 		NULL
 	};
 
-	if (about != NULL)
-	{
-		gtk_window_present (GTK_WINDOW (about));
-
-		return;
-	}
-
-
-	about = g_object_new (GTK_TYPE_ABOUT_DIALOG,
-			      "name", _("Epiphany"),
-			      "version", VERSION,
-			      "copyright", "Copyright \xc2\xa9 2002-2004 Marco Pesenti Gritti",
-			      "authors", authors,
-			      "documenters", documenters,
-			      "translator-credits", _("translator-credits"),
-			      "logo-icon-name", "web-browser",
-			      NULL);
-
-	gtk_window_set_icon_name (GTK_WINDOW (about), "web-browser");
-
-	g_signal_connect (about, "response", G_CALLBACK (gtk_widget_destroy), NULL);
-
-	gtk_window_set_transient_for (GTK_WINDOW (about), GTK_WINDOW (window));
-	gtk_window_set_destroy_with_parent (GTK_WINDOW (about), TRUE);
-
-	ptr = &about;
-	g_object_add_weak_pointer (G_OBJECT (about), (gpointer *)ptr);
-
-	gtk_window_present (GTK_WINDOW (about));
+	gtk_show_about_dialog (GTK_WINDOW (window),
+			       "name", _("Epiphany"),
+			       "version", VERSION,
+			       "copyright", "Copyright \xc2\xa9 2002-2004 Marco Pesenti Gritti",
+			       "authors", authors,
+			       "documenters", documenters,
+			       "translator-credits", _("translator-credits"),
+			       "logo-icon-name", "web-browser",
+			       "website", "http://www.gnome.org/projects/epiphany",
+			       NULL);
 }
 
 void
